from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.name_value_pair import NameValuePair


T = TypeVar("T", bound="ListingsProviderInfo")


@_attrs_define
class ListingsProviderInfo:
    """
    Attributes:
        id (Union[Unset, None, str]):
        type (Union[Unset, None, str]):
        username (Union[Unset, None, str]):
        password (Union[Unset, None, str]):
        listings_id (Union[Unset, None, str]):
        zip_code (Union[Unset, None, str]):
        country (Union[Unset, None, str]):
        path (Union[Unset, None, str]):
        enabled_tuners (Union[Unset, None, List[str]]):
        enable_all_tuners (Union[Unset, bool]):
        news_categories (Union[Unset, None, List[str]]):
        sports_categories (Union[Unset, None, List[str]]):
        kids_categories (Union[Unset, None, List[str]]):
        movie_categories (Union[Unset, None, List[str]]):
        channel_mappings (Union[Unset, None, List['NameValuePair']]):
        movie_prefix (Union[Unset, None, str]):
        preferred_language (Union[Unset, None, str]):
        user_agent (Union[Unset, None, str]):
    """

    id: Union[Unset, None, str] = UNSET
    type: Union[Unset, None, str] = UNSET
    username: Union[Unset, None, str] = UNSET
    password: Union[Unset, None, str] = UNSET
    listings_id: Union[Unset, None, str] = UNSET
    zip_code: Union[Unset, None, str] = UNSET
    country: Union[Unset, None, str] = UNSET
    path: Union[Unset, None, str] = UNSET
    enabled_tuners: Union[Unset, None, List[str]] = UNSET
    enable_all_tuners: Union[Unset, bool] = UNSET
    news_categories: Union[Unset, None, List[str]] = UNSET
    sports_categories: Union[Unset, None, List[str]] = UNSET
    kids_categories: Union[Unset, None, List[str]] = UNSET
    movie_categories: Union[Unset, None, List[str]] = UNSET
    channel_mappings: Union[Unset, None, List["NameValuePair"]] = UNSET
    movie_prefix: Union[Unset, None, str] = UNSET
    preferred_language: Union[Unset, None, str] = UNSET
    user_agent: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        type = self.type
        username = self.username
        password = self.password
        listings_id = self.listings_id
        zip_code = self.zip_code
        country = self.country
        path = self.path
        enabled_tuners: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.enabled_tuners, Unset):
            if self.enabled_tuners is None:
                enabled_tuners = None
            else:
                enabled_tuners = self.enabled_tuners

        enable_all_tuners = self.enable_all_tuners
        news_categories: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.news_categories, Unset):
            if self.news_categories is None:
                news_categories = None
            else:
                news_categories = self.news_categories

        sports_categories: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.sports_categories, Unset):
            if self.sports_categories is None:
                sports_categories = None
            else:
                sports_categories = self.sports_categories

        kids_categories: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.kids_categories, Unset):
            if self.kids_categories is None:
                kids_categories = None
            else:
                kids_categories = self.kids_categories

        movie_categories: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.movie_categories, Unset):
            if self.movie_categories is None:
                movie_categories = None
            else:
                movie_categories = self.movie_categories

        channel_mappings: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.channel_mappings, Unset):
            if self.channel_mappings is None:
                channel_mappings = None
            else:
                channel_mappings = []
                for channel_mappings_item_data in self.channel_mappings:
                    channel_mappings_item = channel_mappings_item_data.to_dict()

                    channel_mappings.append(channel_mappings_item)

        movie_prefix = self.movie_prefix
        preferred_language = self.preferred_language
        user_agent = self.user_agent

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if id is not UNSET:
            field_dict["Id"] = id
        if type is not UNSET:
            field_dict["Type"] = type
        if username is not UNSET:
            field_dict["Username"] = username
        if password is not UNSET:
            field_dict["Password"] = password
        if listings_id is not UNSET:
            field_dict["ListingsId"] = listings_id
        if zip_code is not UNSET:
            field_dict["ZipCode"] = zip_code
        if country is not UNSET:
            field_dict["Country"] = country
        if path is not UNSET:
            field_dict["Path"] = path
        if enabled_tuners is not UNSET:
            field_dict["EnabledTuners"] = enabled_tuners
        if enable_all_tuners is not UNSET:
            field_dict["EnableAllTuners"] = enable_all_tuners
        if news_categories is not UNSET:
            field_dict["NewsCategories"] = news_categories
        if sports_categories is not UNSET:
            field_dict["SportsCategories"] = sports_categories
        if kids_categories is not UNSET:
            field_dict["KidsCategories"] = kids_categories
        if movie_categories is not UNSET:
            field_dict["MovieCategories"] = movie_categories
        if channel_mappings is not UNSET:
            field_dict["ChannelMappings"] = channel_mappings
        if movie_prefix is not UNSET:
            field_dict["MoviePrefix"] = movie_prefix
        if preferred_language is not UNSET:
            field_dict["PreferredLanguage"] = preferred_language
        if user_agent is not UNSET:
            field_dict["UserAgent"] = user_agent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.name_value_pair import NameValuePair

        d = src_dict.copy()
        id = d.pop("Id", UNSET)

        type = d.pop("Type", UNSET)

        username = d.pop("Username", UNSET)

        password = d.pop("Password", UNSET)

        listings_id = d.pop("ListingsId", UNSET)

        zip_code = d.pop("ZipCode", UNSET)

        country = d.pop("Country", UNSET)

        path = d.pop("Path", UNSET)

        enabled_tuners = cast(List[str], d.pop("EnabledTuners", UNSET))

        enable_all_tuners = d.pop("EnableAllTuners", UNSET)

        news_categories = cast(List[str], d.pop("NewsCategories", UNSET))

        sports_categories = cast(List[str], d.pop("SportsCategories", UNSET))

        kids_categories = cast(List[str], d.pop("KidsCategories", UNSET))

        movie_categories = cast(List[str], d.pop("MovieCategories", UNSET))

        channel_mappings = []
        _channel_mappings = d.pop("ChannelMappings", UNSET)
        for channel_mappings_item_data in _channel_mappings or []:
            channel_mappings_item = NameValuePair.from_dict(channel_mappings_item_data)

            channel_mappings.append(channel_mappings_item)

        movie_prefix = d.pop("MoviePrefix", UNSET)

        preferred_language = d.pop("PreferredLanguage", UNSET)

        user_agent = d.pop("UserAgent", UNSET)

        listings_provider_info = cls(
            id=id,
            type=type,
            username=username,
            password=password,
            listings_id=listings_id,
            zip_code=zip_code,
            country=country,
            path=path,
            enabled_tuners=enabled_tuners,
            enable_all_tuners=enable_all_tuners,
            news_categories=news_categories,
            sports_categories=sports_categories,
            kids_categories=kids_categories,
            movie_categories=movie_categories,
            channel_mappings=channel_mappings,
            movie_prefix=movie_prefix,
            preferred_language=preferred_language,
            user_agent=user_agent,
        )

        return listings_provider_info



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.media_source_info import MediaSourceInfo


T = TypeVar("T", bound="LiveStreamResponse")


@_attrs_define
class LiveStreamResponse:
    """
    Attributes:
        media_source (Union[Unset, MediaSourceInfo]):
    """

    media_source: Union[Unset, "MediaSourceInfo"] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        media_source: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.media_source, Unset):
            media_source = self.media_source.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if media_source is not UNSET:
            field_dict["MediaSource"] = media_source

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.media_source_info import MediaSourceInfo

        d = src_dict.copy()
        _media_source = d.pop("MediaSource", UNSET)
        media_source: Union[Unset, MediaSourceInfo]
        if isinstance(_media_source, Unset):
            media_source = UNSET
        else:
            media_source = MediaSourceInfo.from_dict(_media_source)

        live_stream_response = cls(
            media_source=media_source,
        )

        return live_stream_response



""" Contains all the data models used in inputs/outputs """

from .access_schedule import AccessSchedule
from .activity_log_entry import ActivityLogEntry
from .activity_log_entry_query_result import ActivityLogEntryQueryResult
from .add_virtual_folder_dto import AddVirtualFolderDto
from .admin_notification_dto import AdminNotificationDto
from .album_info import AlbumInfo
from .album_info_artist_provider_ids import AlbumInfoArtistProviderIds
from .album_info_provider_ids import AlbumInfoProviderIds
from .album_info_remote_search_query import AlbumInfoRemoteSearchQuery
from .all_theme_media_result import AllThemeMediaResult
from .architecture import Architecture
from .artist_info import ArtistInfo
from .artist_info_provider_ids import ArtistInfoProviderIds
from .artist_info_remote_search_query import ArtistInfoRemoteSearchQuery
from .authenticate_user_by_name import AuthenticateUserByName
from .authentication_info import AuthenticationInfo
from .authentication_info_query_result import AuthenticationInfoQueryResult
from .authentication_result import AuthenticationResult
from .base_item import BaseItem
from .base_item_dto import BaseItemDto
from .base_item_dto_image_blur_hashes import BaseItemDtoImageBlurHashes
from .base_item_dto_image_blur_hashes_art import BaseItemDtoImageBlurHashesArt
from .base_item_dto_image_blur_hashes_backdrop import BaseItemDtoImageBlurHashesBackdrop
from .base_item_dto_image_blur_hashes_banner import BaseItemDtoImageBlurHashesBanner
from .base_item_dto_image_blur_hashes_box import BaseItemDtoImageBlurHashesBox
from .base_item_dto_image_blur_hashes_box_rear import BaseItemDtoImageBlurHashesBoxRear
from .base_item_dto_image_blur_hashes_chapter import BaseItemDtoImageBlurHashesChapter
from .base_item_dto_image_blur_hashes_disc import BaseItemDtoImageBlurHashesDisc
from .base_item_dto_image_blur_hashes_logo import BaseItemDtoImageBlurHashesLogo
from .base_item_dto_image_blur_hashes_menu import BaseItemDtoImageBlurHashesMenu
from .base_item_dto_image_blur_hashes_primary import BaseItemDtoImageBlurHashesPrimary
from .base_item_dto_image_blur_hashes_profile import BaseItemDtoImageBlurHashesProfile
from .base_item_dto_image_blur_hashes_screenshot import BaseItemDtoImageBlurHashesScreenshot
from .base_item_dto_image_blur_hashes_thumb import BaseItemDtoImageBlurHashesThumb
from .base_item_dto_image_tags import BaseItemDtoImageTags
from .base_item_dto_provider_ids import BaseItemDtoProviderIds
from .base_item_dto_query_result import BaseItemDtoQueryResult
from .base_item_kind import BaseItemKind
from .base_item_person import BaseItemPerson
from .base_item_person_image_blur_hashes import BaseItemPersonImageBlurHashes
from .base_item_person_image_blur_hashes_art import BaseItemPersonImageBlurHashesArt
from .base_item_person_image_blur_hashes_backdrop import BaseItemPersonImageBlurHashesBackdrop
from .base_item_person_image_blur_hashes_banner import BaseItemPersonImageBlurHashesBanner
from .base_item_person_image_blur_hashes_box import BaseItemPersonImageBlurHashesBox
from .base_item_person_image_blur_hashes_box_rear import BaseItemPersonImageBlurHashesBoxRear
from .base_item_person_image_blur_hashes_chapter import BaseItemPersonImageBlurHashesChapter
from .base_item_person_image_blur_hashes_disc import BaseItemPersonImageBlurHashesDisc
from .base_item_person_image_blur_hashes_logo import BaseItemPersonImageBlurHashesLogo
from .base_item_person_image_blur_hashes_menu import BaseItemPersonImageBlurHashesMenu
from .base_item_person_image_blur_hashes_primary import BaseItemPersonImageBlurHashesPrimary
from .base_item_person_image_blur_hashes_profile import BaseItemPersonImageBlurHashesProfile
from .base_item_person_image_blur_hashes_screenshot import BaseItemPersonImageBlurHashesScreenshot
from .base_item_person_image_blur_hashes_thumb import BaseItemPersonImageBlurHashesThumb
from .base_plugin_configuration import BasePluginConfiguration
from .book_info import BookInfo
from .book_info_provider_ids import BookInfoProviderIds
from .book_info_remote_search_query import BookInfoRemoteSearchQuery
from .box_set_info import BoxSetInfo
from .box_set_info_provider_ids import BoxSetInfoProviderIds
from .box_set_info_remote_search_query import BoxSetInfoRemoteSearchQuery
from .branding_options import BrandingOptions
from .buffer_request_dto import BufferRequestDto
from .channel_features import ChannelFeatures
from .channel_item_sort_field import ChannelItemSortField
from .channel_mapping_options_dto import ChannelMappingOptionsDto
from .channel_media_content_type import ChannelMediaContentType
from .channel_media_type import ChannelMediaType
from .channel_type import ChannelType
from .chapter_info import ChapterInfo
from .client_capabilities import ClientCapabilities
from .client_capabilities_dto import ClientCapabilitiesDto
from .client_log_document_response_dto import ClientLogDocumentResponseDto
from .codec_profile import CodecProfile
from .codec_type import CodecType
from .collection_creation_result import CollectionCreationResult
from .collection_type_options import CollectionTypeOptions
from .config_image_types import ConfigImageTypes
from .configuration_page_info import ConfigurationPageInfo
from .container_profile import ContainerProfile
from .control_response import ControlResponse
from .control_response_headers import ControlResponseHeaders
from .country_info import CountryInfo
from .create_playlist_dto import CreatePlaylistDto
from .create_user_by_name import CreateUserByName
from .culture_dto import CultureDto
from .day_of_week import DayOfWeek
from .day_pattern import DayPattern
from .default_directory_browser_info_dto import DefaultDirectoryBrowserInfoDto
from .device_identification import DeviceIdentification
from .device_info import DeviceInfo
from .device_info_query_result import DeviceInfoQueryResult
from .device_options import DeviceOptions
from .device_options_dto import DeviceOptionsDto
from .device_profile import DeviceProfile
from .device_profile_info import DeviceProfileInfo
from .device_profile_type import DeviceProfileType
from .direct_play_profile import DirectPlayProfile
from .display_preferences_dto import DisplayPreferencesDto
from .display_preferences_dto_custom_prefs import DisplayPreferencesDtoCustomPrefs
from .dlna_options import DlnaOptions
from .dlna_profile_type import DlnaProfileType
from .dynamic_day_of_week import DynamicDayOfWeek
from .embedded_subtitle_options import EmbeddedSubtitleOptions
from .encoding_context import EncodingContext
from .encoding_options import EncodingOptions
from .end_point_info import EndPointInfo
from .external_id_info import ExternalIdInfo
from .external_id_media_type import ExternalIdMediaType
from .external_url import ExternalUrl
from .f_fmpeg_location import FFmpegLocation
from .file_system_entry_info import FileSystemEntryInfo
from .file_system_entry_type import FileSystemEntryType
from .font_file import FontFile
from .forgot_password_action import ForgotPasswordAction
from .forgot_password_dto import ForgotPasswordDto
from .forgot_password_pin_dto import ForgotPasswordPinDto
from .forgot_password_result import ForgotPasswordResult
from .general_command import GeneralCommand
from .general_command_arguments import GeneralCommandArguments
from .general_command_type import GeneralCommandType
from .get_audio_stream_by_container_stream_options import GetAudioStreamByContainerStreamOptions
from .get_audio_stream_stream_options import GetAudioStreamStreamOptions
from .get_hls_audio_segment_stream_options import GetHlsAudioSegmentStreamOptions
from .get_hls_video_segment_stream_options import GetHlsVideoSegmentStreamOptions
from .get_live_hls_stream_stream_options import GetLiveHlsStreamStreamOptions
from .get_master_hls_audio_playlist_stream_options import GetMasterHlsAudioPlaylistStreamOptions
from .get_master_hls_video_playlist_stream_options import GetMasterHlsVideoPlaylistStreamOptions
from .get_programs_dto import GetProgramsDto
from .get_variant_hls_audio_playlist_stream_options import GetVariantHlsAudioPlaylistStreamOptions
from .get_variant_hls_video_playlist_stream_options import GetVariantHlsVideoPlaylistStreamOptions
from .get_video_stream_by_container_stream_options import GetVideoStreamByContainerStreamOptions
from .get_video_stream_stream_options import GetVideoStreamStreamOptions
from .group_info_dto import GroupInfoDto
from .group_queue_mode import GroupQueueMode
from .group_repeat_mode import GroupRepeatMode
from .group_shuffle_mode import GroupShuffleMode
from .group_state_type import GroupStateType
from .group_update_type import GroupUpdateType
from .guide_info import GuideInfo
from .hardware_encoding_type import HardwareEncodingType
from .head_audio_stream_by_container_stream_options import HeadAudioStreamByContainerStreamOptions
from .head_audio_stream_stream_options import HeadAudioStreamStreamOptions
from .head_master_hls_audio_playlist_stream_options import HeadMasterHlsAudioPlaylistStreamOptions
from .head_master_hls_video_playlist_stream_options import HeadMasterHlsVideoPlaylistStreamOptions
from .head_video_stream_by_container_stream_options import HeadVideoStreamByContainerStreamOptions
from .head_video_stream_stream_options import HeadVideoStreamStreamOptions
from .header_match_type import HeaderMatchType
from .http_header_info import HttpHeaderInfo
from .i_plugin import IPlugin
from .ignore_wait_request_dto import IgnoreWaitRequestDto
from .image_by_name_info import ImageByNameInfo
from .image_format import ImageFormat
from .image_info import ImageInfo
from .image_option import ImageOption
from .image_orientation import ImageOrientation
from .image_provider_info import ImageProviderInfo
from .image_saving_convention import ImageSavingConvention
from .image_type import ImageType
from .installation_info import InstallationInfo
from .iso_type import IsoType
from .item_counts import ItemCounts
from .item_fields import ItemFields
from .item_filter import ItemFilter
from .join_group_request_dto import JoinGroupRequestDto
from .keep_until import KeepUntil
from .library_option_info_dto import LibraryOptionInfoDto
from .library_options import LibraryOptions
from .library_options_result_dto import LibraryOptionsResultDto
from .library_type_options_dto import LibraryTypeOptionsDto
from .library_update_info import LibraryUpdateInfo
from .listings_provider_info import ListingsProviderInfo
from .live_stream_response import LiveStreamResponse
from .live_tv_info import LiveTvInfo
from .live_tv_options import LiveTvOptions
from .live_tv_service_info import LiveTvServiceInfo
from .live_tv_service_status import LiveTvServiceStatus
from .localization_option import LocalizationOption
from .location_type import LocationType
from .log_file import LogFile
from .log_level import LogLevel
from .media_attachment import MediaAttachment
from .media_encoder_path_dto import MediaEncoderPathDto
from .media_path_dto import MediaPathDto
from .media_path_info import MediaPathInfo
from .media_protocol import MediaProtocol
from .media_source_info import MediaSourceInfo
from .media_source_info_required_http_headers import MediaSourceInfoRequiredHttpHeaders
from .media_source_type import MediaSourceType
from .media_stream import MediaStream
from .media_stream_type import MediaStreamType
from .media_update_info_dto import MediaUpdateInfoDto
from .media_update_info_path_dto import MediaUpdateInfoPathDto
from .media_url import MediaUrl
from .message_command import MessageCommand
from .metadata_configuration import MetadataConfiguration
from .metadata_editor_info import MetadataEditorInfo
from .metadata_field import MetadataField
from .metadata_options import MetadataOptions
from .metadata_refresh_mode import MetadataRefreshMode
from .move_playlist_item_request_dto import MovePlaylistItemRequestDto
from .movie_info import MovieInfo
from .movie_info_provider_ids import MovieInfoProviderIds
from .movie_info_remote_search_query import MovieInfoRemoteSearchQuery
from .music_video_info import MusicVideoInfo
from .music_video_info_provider_ids import MusicVideoInfoProviderIds
from .music_video_info_remote_search_query import MusicVideoInfoRemoteSearchQuery
from .name_guid_pair import NameGuidPair
from .name_id_pair import NameIdPair
from .name_value_pair import NameValuePair
from .network_configuration import NetworkConfiguration
from .new_group_request_dto import NewGroupRequestDto
from .next_item_request_dto import NextItemRequestDto
from .notification_dto import NotificationDto
from .notification_level import NotificationLevel
from .notification_option import NotificationOption
from .notification_options import NotificationOptions
from .notification_result_dto import NotificationResultDto
from .notification_type_info import NotificationTypeInfo
from .notifications_summary_dto import NotificationsSummaryDto
from .object_group_update import ObjectGroupUpdate
from .open_live_stream_dto import OpenLiveStreamDto
from .package_info import PackageInfo
from .parental_rating import ParentalRating
from .path_substitution import PathSubstitution
from .person_lookup_info import PersonLookupInfo
from .person_lookup_info_provider_ids import PersonLookupInfoProviderIds
from .person_lookup_info_remote_search_query import PersonLookupInfoRemoteSearchQuery
from .pin_redeem_result import PinRedeemResult
from .ping_request_dto import PingRequestDto
from .play_access import PlayAccess
from .play_command import PlayCommand
from .play_method import PlayMethod
from .play_request import PlayRequest
from .play_request_dto import PlayRequestDto
from .playback_error_code import PlaybackErrorCode
from .playback_info_dto import PlaybackInfoDto
from .playback_info_response import PlaybackInfoResponse
from .playback_progress_info import PlaybackProgressInfo
from .playback_start_info import PlaybackStartInfo
from .playback_stop_info import PlaybackStopInfo
from .player_state_info import PlayerStateInfo
from .playlist_creation_result import PlaylistCreationResult
from .playstate_command import PlaystateCommand
from .playstate_request import PlaystateRequest
from .plugin_info import PluginInfo
from .plugin_status import PluginStatus
from .previous_item_request_dto import PreviousItemRequestDto
from .problem_details import ProblemDetails
from .profile_condition import ProfileCondition
from .profile_condition_type import ProfileConditionType
from .profile_condition_value import ProfileConditionValue
from .program_audio import ProgramAudio
from .public_system_info import PublicSystemInfo
from .query_filters import QueryFilters
from .query_filters_legacy import QueryFiltersLegacy
from .queue_item import QueueItem
from .queue_request_dto import QueueRequestDto
from .quick_connect_dto import QuickConnectDto
from .quick_connect_result import QuickConnectResult
from .rating_type import RatingType
from .ready_request_dto import ReadyRequestDto
from .recommendation_dto import RecommendationDto
from .recommendation_type import RecommendationType
from .recording_status import RecordingStatus
from .remote_image_info import RemoteImageInfo
from .remote_image_result import RemoteImageResult
from .remote_search_result import RemoteSearchResult
from .remote_search_result_provider_ids import RemoteSearchResultProviderIds
from .remote_subtitle_info import RemoteSubtitleInfo
from .remove_from_playlist_request_dto import RemoveFromPlaylistRequestDto
from .repeat_mode import RepeatMode
from .repository_info import RepositoryInfo
from .response_profile import ResponseProfile
from .scroll_direction import ScrollDirection
from .search_hint import SearchHint
from .search_hint_result import SearchHintResult
from .seek_request_dto import SeekRequestDto
from .send_command import SendCommand
from .send_command_type import SendCommandType
from .send_to_user_type import SendToUserType
from .series_info import SeriesInfo
from .series_info_provider_ids import SeriesInfoProviderIds
from .series_info_remote_search_query import SeriesInfoRemoteSearchQuery
from .series_status import SeriesStatus
from .series_timer_info_dto import SeriesTimerInfoDto
from .series_timer_info_dto_image_tags import SeriesTimerInfoDtoImageTags
from .series_timer_info_dto_query_result import SeriesTimerInfoDtoQueryResult
from .server_configuration import ServerConfiguration
from .server_discovery_info import ServerDiscoveryInfo
from .session_info import SessionInfo
from .session_message_type import SessionMessageType
from .session_user_info import SessionUserInfo
from .set_channel_mapping_dto import SetChannelMappingDto
from .set_playlist_item_request_dto import SetPlaylistItemRequestDto
from .set_repeat_mode_request_dto import SetRepeatModeRequestDto
from .set_shuffle_mode_request_dto import SetShuffleModeRequestDto
from .song_info import SongInfo
from .song_info_provider_ids import SongInfoProviderIds
from .sort_order import SortOrder
from .special_view_option_dto import SpecialViewOptionDto
from .startup_configuration_dto import StartupConfigurationDto
from .startup_remote_access_dto import StartupRemoteAccessDto
from .startup_user_dto import StartupUserDto
from .subtitle_delivery_method import SubtitleDeliveryMethod
from .subtitle_options import SubtitleOptions
from .subtitle_playback_mode import SubtitlePlaybackMode
from .subtitle_profile import SubtitleProfile
from .sync_play_user_access_type import SyncPlayUserAccessType
from .system_info import SystemInfo
from .task_completion_status import TaskCompletionStatus
from .task_info import TaskInfo
from .task_result import TaskResult
from .task_state import TaskState
from .task_trigger_info import TaskTriggerInfo
from .theme_media_result import ThemeMediaResult
from .timer_event_info import TimerEventInfo
from .timer_info_dto import TimerInfoDto
from .timer_info_dto_query_result import TimerInfoDtoQueryResult
from .trailer_info import TrailerInfo
from .trailer_info_provider_ids import TrailerInfoProviderIds
from .trailer_info_remote_search_query import TrailerInfoRemoteSearchQuery
from .transcode_reason import TranscodeReason
from .transcode_seek_info import TranscodeSeekInfo
from .transcoding_info import TranscodingInfo
from .transcoding_profile import TranscodingProfile
from .transport_stream_timestamp import TransportStreamTimestamp
from .tuner_channel_mapping import TunerChannelMapping
from .tuner_host_info import TunerHostInfo
from .type_options import TypeOptions
from .unrated_item import UnratedItem
from .update_library_options_dto import UpdateLibraryOptionsDto
from .update_media_path_request_dto import UpdateMediaPathRequestDto
from .update_user_easy_password import UpdateUserEasyPassword
from .update_user_password import UpdateUserPassword
from .upload_subtitle_dto import UploadSubtitleDto
from .user_configuration import UserConfiguration
from .user_dto import UserDto
from .user_item_data_dto import UserItemDataDto
from .user_policy import UserPolicy
from .utc_time_response import UtcTimeResponse
from .validate_path_dto import ValidatePathDto
from .version_info import VersionInfo
from .video_3d_format import Video3DFormat
from .video_type import VideoType
from .virtual_folder_info import VirtualFolderInfo
from .wake_on_lan_info import WakeOnLanInfo
from .xbmc_metadata_options import XbmcMetadataOptions
from .xml_attribute import XmlAttribute

__all__ = (
    "AccessSchedule",
    "ActivityLogEntry",
    "ActivityLogEntryQueryResult",
    "AddVirtualFolderDto",
    "AdminNotificationDto",
    "AlbumInfo",
    "AlbumInfoArtistProviderIds",
    "AlbumInfoProviderIds",
    "AlbumInfoRemoteSearchQuery",
    "AllThemeMediaResult",
    "Architecture",
    "ArtistInfo",
    "ArtistInfoProviderIds",
    "ArtistInfoRemoteSearchQuery",
    "AuthenticateUserByName",
    "AuthenticationInfo",
    "AuthenticationInfoQueryResult",
    "AuthenticationResult",
    "BaseItem",
    "BaseItemDto",
    "BaseItemDtoImageBlurHashes",
    "BaseItemDtoImageBlurHashesArt",
    "BaseItemDtoImageBlurHashesBackdrop",
    "BaseItemDtoImageBlurHashesBanner",
    "BaseItemDtoImageBlurHashesBox",
    "BaseItemDtoImageBlurHashesBoxRear",
    "BaseItemDtoImageBlurHashesChapter",
    "BaseItemDtoImageBlurHashesDisc",
    "BaseItemDtoImageBlurHashesLogo",
    "BaseItemDtoImageBlurHashesMenu",
    "BaseItemDtoImageBlurHashesPrimary",
    "BaseItemDtoImageBlurHashesProfile",
    "BaseItemDtoImageBlurHashesScreenshot",
    "BaseItemDtoImageBlurHashesThumb",
    "BaseItemDtoImageTags",
    "BaseItemDtoProviderIds",
    "BaseItemDtoQueryResult",
    "BaseItemKind",
    "BaseItemPerson",
    "BaseItemPersonImageBlurHashes",
    "BaseItemPersonImageBlurHashesArt",
    "BaseItemPersonImageBlurHashesBackdrop",
    "BaseItemPersonImageBlurHashesBanner",
    "BaseItemPersonImageBlurHashesBox",
    "BaseItemPersonImageBlurHashesBoxRear",
    "BaseItemPersonImageBlurHashesChapter",
    "BaseItemPersonImageBlurHashesDisc",
    "BaseItemPersonImageBlurHashesLogo",
    "BaseItemPersonImageBlurHashesMenu",
    "BaseItemPersonImageBlurHashesPrimary",
    "BaseItemPersonImageBlurHashesProfile",
    "BaseItemPersonImageBlurHashesScreenshot",
    "BaseItemPersonImageBlurHashesThumb",
    "BasePluginConfiguration",
    "BookInfo",
    "BookInfoProviderIds",
    "BookInfoRemoteSearchQuery",
    "BoxSetInfo",
    "BoxSetInfoProviderIds",
    "BoxSetInfoRemoteSearchQuery",
    "BrandingOptions",
    "BufferRequestDto",
    "ChannelFeatures",
    "ChannelItemSortField",
    "ChannelMappingOptionsDto",
    "ChannelMediaContentType",
    "ChannelMediaType",
    "ChannelType",
    "ChapterInfo",
    "ClientCapabilities",
    "ClientCapabilitiesDto",
    "ClientLogDocumentResponseDto",
    "CodecProfile",
    "CodecType",
    "CollectionCreationResult",
    "CollectionTypeOptions",
    "ConfigImageTypes",
    "ConfigurationPageInfo",
    "ContainerProfile",
    "ControlResponse",
    "ControlResponseHeaders",
    "CountryInfo",
    "CreatePlaylistDto",
    "CreateUserByName",
    "CultureDto",
    "DayOfWeek",
    "DayPattern",
    "DefaultDirectoryBrowserInfoDto",
    "DeviceIdentification",
    "DeviceInfo",
    "DeviceInfoQueryResult",
    "DeviceOptions",
    "DeviceOptionsDto",
    "DeviceProfile",
    "DeviceProfileInfo",
    "DeviceProfileType",
    "DirectPlayProfile",
    "DisplayPreferencesDto",
    "DisplayPreferencesDtoCustomPrefs",
    "DlnaOptions",
    "DlnaProfileType",
    "DynamicDayOfWeek",
    "EmbeddedSubtitleOptions",
    "EncodingContext",
    "EncodingOptions",
    "EndPointInfo",
    "ExternalIdInfo",
    "ExternalIdMediaType",
    "ExternalUrl",
    "FFmpegLocation",
    "FileSystemEntryInfo",
    "FileSystemEntryType",
    "FontFile",
    "ForgotPasswordAction",
    "ForgotPasswordDto",
    "ForgotPasswordPinDto",
    "ForgotPasswordResult",
    "GeneralCommand",
    "GeneralCommandArguments",
    "GeneralCommandType",
    "GetAudioStreamByContainerStreamOptions",
    "GetAudioStreamStreamOptions",
    "GetHlsAudioSegmentStreamOptions",
    "GetHlsVideoSegmentStreamOptions",
    "GetLiveHlsStreamStreamOptions",
    "GetMasterHlsAudioPlaylistStreamOptions",
    "GetMasterHlsVideoPlaylistStreamOptions",
    "GetProgramsDto",
    "GetVariantHlsAudioPlaylistStreamOptions",
    "GetVariantHlsVideoPlaylistStreamOptions",
    "GetVideoStreamByContainerStreamOptions",
    "GetVideoStreamStreamOptions",
    "GroupInfoDto",
    "GroupQueueMode",
    "GroupRepeatMode",
    "GroupShuffleMode",
    "GroupStateType",
    "GroupUpdateType",
    "GuideInfo",
    "HardwareEncodingType",
    "HeadAudioStreamByContainerStreamOptions",
    "HeadAudioStreamStreamOptions",
    "HeaderMatchType",
    "HeadMasterHlsAudioPlaylistStreamOptions",
    "HeadMasterHlsVideoPlaylistStreamOptions",
    "HeadVideoStreamByContainerStreamOptions",
    "HeadVideoStreamStreamOptions",
    "HttpHeaderInfo",
    "IgnoreWaitRequestDto",
    "ImageByNameInfo",
    "ImageFormat",
    "ImageInfo",
    "ImageOption",
    "ImageOrientation",
    "ImageProviderInfo",
    "ImageSavingConvention",
    "ImageType",
    "InstallationInfo",
    "IPlugin",
    "IsoType",
    "ItemCounts",
    "ItemFields",
    "ItemFilter",
    "JoinGroupRequestDto",
    "KeepUntil",
    "LibraryOptionInfoDto",
    "LibraryOptions",
    "LibraryOptionsResultDto",
    "LibraryTypeOptionsDto",
    "LibraryUpdateInfo",
    "ListingsProviderInfo",
    "LiveStreamResponse",
    "LiveTvInfo",
    "LiveTvOptions",
    "LiveTvServiceInfo",
    "LiveTvServiceStatus",
    "LocalizationOption",
    "LocationType",
    "LogFile",
    "LogLevel",
    "MediaAttachment",
    "MediaEncoderPathDto",
    "MediaPathDto",
    "MediaPathInfo",
    "MediaProtocol",
    "MediaSourceInfo",
    "MediaSourceInfoRequiredHttpHeaders",
    "MediaSourceType",
    "MediaStream",
    "MediaStreamType",
    "MediaUpdateInfoDto",
    "MediaUpdateInfoPathDto",
    "MediaUrl",
    "MessageCommand",
    "MetadataConfiguration",
    "MetadataEditorInfo",
    "MetadataField",
    "MetadataOptions",
    "MetadataRefreshMode",
    "MovePlaylistItemRequestDto",
    "MovieInfo",
    "MovieInfoProviderIds",
    "MovieInfoRemoteSearchQuery",
    "MusicVideoInfo",
    "MusicVideoInfoProviderIds",
    "MusicVideoInfoRemoteSearchQuery",
    "NameGuidPair",
    "NameIdPair",
    "NameValuePair",
    "NetworkConfiguration",
    "NewGroupRequestDto",
    "NextItemRequestDto",
    "NotificationDto",
    "NotificationLevel",
    "NotificationOption",
    "NotificationOptions",
    "NotificationResultDto",
    "NotificationsSummaryDto",
    "NotificationTypeInfo",
    "ObjectGroupUpdate",
    "OpenLiveStreamDto",
    "PackageInfo",
    "ParentalRating",
    "PathSubstitution",
    "PersonLookupInfo",
    "PersonLookupInfoProviderIds",
    "PersonLookupInfoRemoteSearchQuery",
    "PingRequestDto",
    "PinRedeemResult",
    "PlayAccess",
    "PlaybackErrorCode",
    "PlaybackInfoDto",
    "PlaybackInfoResponse",
    "PlaybackProgressInfo",
    "PlaybackStartInfo",
    "PlaybackStopInfo",
    "PlayCommand",
    "PlayerStateInfo",
    "PlaylistCreationResult",
    "PlayMethod",
    "PlayRequest",
    "PlayRequestDto",
    "PlaystateCommand",
    "PlaystateRequest",
    "PluginInfo",
    "PluginStatus",
    "PreviousItemRequestDto",
    "ProblemDetails",
    "ProfileCondition",
    "ProfileConditionType",
    "ProfileConditionValue",
    "ProgramAudio",
    "PublicSystemInfo",
    "QueryFilters",
    "QueryFiltersLegacy",
    "QueueItem",
    "QueueRequestDto",
    "QuickConnectDto",
    "QuickConnectResult",
    "RatingType",
    "ReadyRequestDto",
    "RecommendationDto",
    "RecommendationType",
    "RecordingStatus",
    "RemoteImageInfo",
    "RemoteImageResult",
    "RemoteSearchResult",
    "RemoteSearchResultProviderIds",
    "RemoteSubtitleInfo",
    "RemoveFromPlaylistRequestDto",
    "RepeatMode",
    "RepositoryInfo",
    "ResponseProfile",
    "ScrollDirection",
    "SearchHint",
    "SearchHintResult",
    "SeekRequestDto",
    "SendCommand",
    "SendCommandType",
    "SendToUserType",
    "SeriesInfo",
    "SeriesInfoProviderIds",
    "SeriesInfoRemoteSearchQuery",
    "SeriesStatus",
    "SeriesTimerInfoDto",
    "SeriesTimerInfoDtoImageTags",
    "SeriesTimerInfoDtoQueryResult",
    "ServerConfiguration",
    "ServerDiscoveryInfo",
    "SessionInfo",
    "SessionMessageType",
    "SessionUserInfo",
    "SetChannelMappingDto",
    "SetPlaylistItemRequestDto",
    "SetRepeatModeRequestDto",
    "SetShuffleModeRequestDto",
    "SongInfo",
    "SongInfoProviderIds",
    "SortOrder",
    "SpecialViewOptionDto",
    "StartupConfigurationDto",
    "StartupRemoteAccessDto",
    "StartupUserDto",
    "SubtitleDeliveryMethod",
    "SubtitleOptions",
    "SubtitlePlaybackMode",
    "SubtitleProfile",
    "SyncPlayUserAccessType",
    "SystemInfo",
    "TaskCompletionStatus",
    "TaskInfo",
    "TaskResult",
    "TaskState",
    "TaskTriggerInfo",
    "ThemeMediaResult",
    "TimerEventInfo",
    "TimerInfoDto",
    "TimerInfoDtoQueryResult",
    "TrailerInfo",
    "TrailerInfoProviderIds",
    "TrailerInfoRemoteSearchQuery",
    "TranscodeReason",
    "TranscodeSeekInfo",
    "TranscodingInfo",
    "TranscodingProfile",
    "TransportStreamTimestamp",
    "TunerChannelMapping",
    "TunerHostInfo",
    "TypeOptions",
    "UnratedItem",
    "UpdateLibraryOptionsDto",
    "UpdateMediaPathRequestDto",
    "UpdateUserEasyPassword",
    "UpdateUserPassword",
    "UploadSubtitleDto",
    "UserConfiguration",
    "UserDto",
    "UserItemDataDto",
    "UserPolicy",
    "UtcTimeResponse",
    "ValidatePathDto",
    "VersionInfo",
    "Video3DFormat",
    "VideoType",
    "VirtualFolderInfo",
    "WakeOnLanInfo",
    "XbmcMetadataOptions",
    "XmlAttribute",
)



from enum import Enum


class SendCommandType(str, Enum):
    PAUSE = "Pause"
    SEEK = "Seek"
    STOP = "Stop"
    UNPAUSE = "Unpause"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.series_timer_info_dto import SeriesTimerInfoDto


T = TypeVar("T", bound="SeriesTimerInfoDtoQueryResult")


@_attrs_define
class SeriesTimerInfoDtoQueryResult:
    """
    Attributes:
        items (Union[Unset, None, List['SeriesTimerInfoDto']]): Gets or sets the items.
        total_record_count (Union[Unset, int]): Gets or sets the total number of records available.
        start_index (Union[Unset, int]): Gets or sets the index of the first record in Items.
    """

    items: Union[Unset, None, List["SeriesTimerInfoDto"]] = UNSET
    total_record_count: Union[Unset, int] = UNSET
    start_index: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        items: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.items, Unset):
            if self.items is None:
                items = None
            else:
                items = []
                for items_item_data in self.items:
                    items_item = items_item_data.to_dict()

                    items.append(items_item)

        total_record_count = self.total_record_count
        start_index = self.start_index

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if items is not UNSET:
            field_dict["Items"] = items
        if total_record_count is not UNSET:
            field_dict["TotalRecordCount"] = total_record_count
        if start_index is not UNSET:
            field_dict["StartIndex"] = start_index

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.series_timer_info_dto import SeriesTimerInfoDto

        d = src_dict.copy()
        items = []
        _items = d.pop("Items", UNSET)
        for items_item_data in _items or []:
            items_item = SeriesTimerInfoDto.from_dict(items_item_data)

            items.append(items_item)

        total_record_count = d.pop("TotalRecordCount", UNSET)

        start_index = d.pop("StartIndex", UNSET)

        series_timer_info_dto_query_result = cls(
            items=items,
            total_record_count=total_record_count,
            start_index=start_index,
        )

        return series_timer_info_dto_query_result



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.live_tv_service_info import LiveTvServiceInfo


T = TypeVar("T", bound="LiveTvInfo")


@_attrs_define
class LiveTvInfo:
    """
    Attributes:
        services (Union[Unset, List['LiveTvServiceInfo']]): Gets or sets the services.
        is_enabled (Union[Unset, bool]): Gets or sets a value indicating whether this instance is enabled.
        enabled_users (Union[Unset, List[str]]): Gets or sets the enabled users.
    """

    services: Union[Unset, List["LiveTvServiceInfo"]] = UNSET
    is_enabled: Union[Unset, bool] = UNSET
    enabled_users: Union[Unset, List[str]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        services: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.services, Unset):
            services = []
            for services_item_data in self.services:
                services_item = services_item_data.to_dict()

                services.append(services_item)

        is_enabled = self.is_enabled
        enabled_users: Union[Unset, List[str]] = UNSET
        if not isinstance(self.enabled_users, Unset):
            enabled_users = self.enabled_users

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if services is not UNSET:
            field_dict["Services"] = services
        if is_enabled is not UNSET:
            field_dict["IsEnabled"] = is_enabled
        if enabled_users is not UNSET:
            field_dict["EnabledUsers"] = enabled_users

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.live_tv_service_info import LiveTvServiceInfo

        d = src_dict.copy()
        services = []
        _services = d.pop("Services", UNSET)
        for services_item_data in _services or []:
            services_item = LiveTvServiceInfo.from_dict(services_item_data)

            services.append(services_item)

        is_enabled = d.pop("IsEnabled", UNSET)

        enabled_users = cast(List[str], d.pop("EnabledUsers", UNSET))

        live_tv_info = cls(
            services=services,
            is_enabled=is_enabled,
            enabled_users=enabled_users,
        )

        return live_tv_info



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="ImageByNameInfo")


@_attrs_define
class ImageByNameInfo:
    """
    Attributes:
        name (Union[Unset, None, str]): Gets or sets the name.
        theme (Union[Unset, None, str]): Gets or sets the theme.
        context (Union[Unset, None, str]): Gets or sets the context.
        file_length (Union[Unset, int]): Gets or sets the length of the file.
        format_ (Union[Unset, None, str]): Gets or sets the format.
    """

    name: Union[Unset, None, str] = UNSET
    theme: Union[Unset, None, str] = UNSET
    context: Union[Unset, None, str] = UNSET
    file_length: Union[Unset, int] = UNSET
    format_: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        theme = self.theme
        context = self.context
        file_length = self.file_length
        format_ = self.format_

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if theme is not UNSET:
            field_dict["Theme"] = theme
        if context is not UNSET:
            field_dict["Context"] = context
        if file_length is not UNSET:
            field_dict["FileLength"] = file_length
        if format_ is not UNSET:
            field_dict["Format"] = format_

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        theme = d.pop("Theme", UNSET)

        context = d.pop("Context", UNSET)

        file_length = d.pop("FileLength", UNSET)

        format_ = d.pop("Format", UNSET)

        image_by_name_info = cls(
            name=name,
            theme=theme,
            context=context,
            file_length=file_length,
            format_=format_,
        )

        return image_by_name_info



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="MetadataOptions")


@_attrs_define
class MetadataOptions:
    """Class MetadataOptions.

    Attributes:
        item_type (Union[Unset, None, str]):
        disabled_metadata_savers (Union[Unset, None, List[str]]):
        local_metadata_reader_order (Union[Unset, None, List[str]]):
        disabled_metadata_fetchers (Union[Unset, None, List[str]]):
        metadata_fetcher_order (Union[Unset, None, List[str]]):
        disabled_image_fetchers (Union[Unset, None, List[str]]):
        image_fetcher_order (Union[Unset, None, List[str]]):
    """

    item_type: Union[Unset, None, str] = UNSET
    disabled_metadata_savers: Union[Unset, None, List[str]] = UNSET
    local_metadata_reader_order: Union[Unset, None, List[str]] = UNSET
    disabled_metadata_fetchers: Union[Unset, None, List[str]] = UNSET
    metadata_fetcher_order: Union[Unset, None, List[str]] = UNSET
    disabled_image_fetchers: Union[Unset, None, List[str]] = UNSET
    image_fetcher_order: Union[Unset, None, List[str]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        item_type = self.item_type
        disabled_metadata_savers: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.disabled_metadata_savers, Unset):
            if self.disabled_metadata_savers is None:
                disabled_metadata_savers = None
            else:
                disabled_metadata_savers = self.disabled_metadata_savers

        local_metadata_reader_order: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.local_metadata_reader_order, Unset):
            if self.local_metadata_reader_order is None:
                local_metadata_reader_order = None
            else:
                local_metadata_reader_order = self.local_metadata_reader_order

        disabled_metadata_fetchers: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.disabled_metadata_fetchers, Unset):
            if self.disabled_metadata_fetchers is None:
                disabled_metadata_fetchers = None
            else:
                disabled_metadata_fetchers = self.disabled_metadata_fetchers

        metadata_fetcher_order: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.metadata_fetcher_order, Unset):
            if self.metadata_fetcher_order is None:
                metadata_fetcher_order = None
            else:
                metadata_fetcher_order = self.metadata_fetcher_order

        disabled_image_fetchers: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.disabled_image_fetchers, Unset):
            if self.disabled_image_fetchers is None:
                disabled_image_fetchers = None
            else:
                disabled_image_fetchers = self.disabled_image_fetchers

        image_fetcher_order: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.image_fetcher_order, Unset):
            if self.image_fetcher_order is None:
                image_fetcher_order = None
            else:
                image_fetcher_order = self.image_fetcher_order

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if item_type is not UNSET:
            field_dict["ItemType"] = item_type
        if disabled_metadata_savers is not UNSET:
            field_dict["DisabledMetadataSavers"] = disabled_metadata_savers
        if local_metadata_reader_order is not UNSET:
            field_dict["LocalMetadataReaderOrder"] = local_metadata_reader_order
        if disabled_metadata_fetchers is not UNSET:
            field_dict["DisabledMetadataFetchers"] = disabled_metadata_fetchers
        if metadata_fetcher_order is not UNSET:
            field_dict["MetadataFetcherOrder"] = metadata_fetcher_order
        if disabled_image_fetchers is not UNSET:
            field_dict["DisabledImageFetchers"] = disabled_image_fetchers
        if image_fetcher_order is not UNSET:
            field_dict["ImageFetcherOrder"] = image_fetcher_order

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        item_type = d.pop("ItemType", UNSET)

        disabled_metadata_savers = cast(List[str], d.pop("DisabledMetadataSavers", UNSET))

        local_metadata_reader_order = cast(List[str], d.pop("LocalMetadataReaderOrder", UNSET))

        disabled_metadata_fetchers = cast(List[str], d.pop("DisabledMetadataFetchers", UNSET))

        metadata_fetcher_order = cast(List[str], d.pop("MetadataFetcherOrder", UNSET))

        disabled_image_fetchers = cast(List[str], d.pop("DisabledImageFetchers", UNSET))

        image_fetcher_order = cast(List[str], d.pop("ImageFetcherOrder", UNSET))

        metadata_options = cls(
            item_type=item_type,
            disabled_metadata_savers=disabled_metadata_savers,
            local_metadata_reader_order=local_metadata_reader_order,
            disabled_metadata_fetchers=disabled_metadata_fetchers,
            metadata_fetcher_order=metadata_fetcher_order,
            disabled_image_fetchers=disabled_image_fetchers,
            image_fetcher_order=image_fetcher_order,
        )

        return metadata_options



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.device_profile_type import DeviceProfileType
from ..types import UNSET, Unset

T = TypeVar("T", bound="DeviceProfileInfo")


@_attrs_define
class DeviceProfileInfo:
    """
    Attributes:
        id (Union[Unset, None, str]): Gets or sets the identifier.
        name (Union[Unset, None, str]): Gets or sets the name.
        type (Union[Unset, DeviceProfileType]):
    """

    id: Union[Unset, None, str] = UNSET
    name: Union[Unset, None, str] = UNSET
    type: Union[Unset, DeviceProfileType] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        name = self.name
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if id is not UNSET:
            field_dict["Id"] = id
        if name is not UNSET:
            field_dict["Name"] = name
        if type is not UNSET:
            field_dict["Type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("Id", UNSET)

        name = d.pop("Name", UNSET)

        _type = d.pop("Type", UNSET)
        type: Union[Unset, DeviceProfileType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = DeviceProfileType(_type)

        device_profile_info = cls(
            id=id,
            name=name,
            type=type,
        )

        return device_profile_info



import datetime
from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="AuthenticationInfo")


@_attrs_define
class AuthenticationInfo:
    """
    Attributes:
        id (Union[Unset, int]): Gets or sets the identifier.
        access_token (Union[Unset, None, str]): Gets or sets the access token.
        device_id (Union[Unset, None, str]): Gets or sets the device identifier.
        app_name (Union[Unset, None, str]): Gets or sets the name of the application.
        app_version (Union[Unset, None, str]): Gets or sets the application version.
        device_name (Union[Unset, None, str]): Gets or sets the name of the device.
        user_id (Union[Unset, str]): Gets or sets the user identifier.
        is_active (Union[Unset, bool]): Gets or sets a value indicating whether this instance is active.
        date_created (Union[Unset, datetime.datetime]): Gets or sets the date created.
        date_revoked (Union[Unset, None, datetime.datetime]): Gets or sets the date revoked.
        date_last_activity (Union[Unset, datetime.datetime]):
        user_name (Union[Unset, None, str]):
    """

    id: Union[Unset, int] = UNSET
    access_token: Union[Unset, None, str] = UNSET
    device_id: Union[Unset, None, str] = UNSET
    app_name: Union[Unset, None, str] = UNSET
    app_version: Union[Unset, None, str] = UNSET
    device_name: Union[Unset, None, str] = UNSET
    user_id: Union[Unset, str] = UNSET
    is_active: Union[Unset, bool] = UNSET
    date_created: Union[Unset, datetime.datetime] = UNSET
    date_revoked: Union[Unset, None, datetime.datetime] = UNSET
    date_last_activity: Union[Unset, datetime.datetime] = UNSET
    user_name: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        access_token = self.access_token
        device_id = self.device_id
        app_name = self.app_name
        app_version = self.app_version
        device_name = self.device_name
        user_id = self.user_id
        is_active = self.is_active
        date_created: Union[Unset, str] = UNSET
        if not isinstance(self.date_created, Unset):
            date_created = self.date_created.isoformat()

        date_revoked: Union[Unset, None, str] = UNSET
        if not isinstance(self.date_revoked, Unset):
            date_revoked = self.date_revoked.isoformat() if self.date_revoked else None

        date_last_activity: Union[Unset, str] = UNSET
        if not isinstance(self.date_last_activity, Unset):
            date_last_activity = self.date_last_activity.isoformat()

        user_name = self.user_name

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if id is not UNSET:
            field_dict["Id"] = id
        if access_token is not UNSET:
            field_dict["AccessToken"] = access_token
        if device_id is not UNSET:
            field_dict["DeviceId"] = device_id
        if app_name is not UNSET:
            field_dict["AppName"] = app_name
        if app_version is not UNSET:
            field_dict["AppVersion"] = app_version
        if device_name is not UNSET:
            field_dict["DeviceName"] = device_name
        if user_id is not UNSET:
            field_dict["UserId"] = user_id
        if is_active is not UNSET:
            field_dict["IsActive"] = is_active
        if date_created is not UNSET:
            field_dict["DateCreated"] = date_created
        if date_revoked is not UNSET:
            field_dict["DateRevoked"] = date_revoked
        if date_last_activity is not UNSET:
            field_dict["DateLastActivity"] = date_last_activity
        if user_name is not UNSET:
            field_dict["UserName"] = user_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("Id", UNSET)

        access_token = d.pop("AccessToken", UNSET)

        device_id = d.pop("DeviceId", UNSET)

        app_name = d.pop("AppName", UNSET)

        app_version = d.pop("AppVersion", UNSET)

        device_name = d.pop("DeviceName", UNSET)

        user_id = d.pop("UserId", UNSET)

        is_active = d.pop("IsActive", UNSET)

        _date_created = d.pop("DateCreated", UNSET)
        date_created: Union[Unset, datetime.datetime]
        if isinstance(_date_created, Unset):
            date_created = UNSET
        else:
            date_created = isoparse(_date_created)

        _date_revoked = d.pop("DateRevoked", UNSET)
        date_revoked: Union[Unset, None, datetime.datetime]
        if _date_revoked is None:
            date_revoked = None
        elif isinstance(_date_revoked, Unset):
            date_revoked = UNSET
        else:
            date_revoked = isoparse(_date_revoked)

        _date_last_activity = d.pop("DateLastActivity", UNSET)
        date_last_activity: Union[Unset, datetime.datetime]
        if isinstance(_date_last_activity, Unset):
            date_last_activity = UNSET
        else:
            date_last_activity = isoparse(_date_last_activity)

        user_name = d.pop("UserName", UNSET)

        authentication_info = cls(
            id=id,
            access_token=access_token,
            device_id=device_id,
            app_name=app_name,
            app_version=app_version,
            device_name=device_name,
            user_id=user_id,
            is_active=is_active,
            date_created=date_created,
            date_revoked=date_revoked,
            date_last_activity=date_last_activity,
            user_name=user_name,
        )

        return authentication_info



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="SeekRequestDto")


@_attrs_define
class SeekRequestDto:
    """Class SeekRequestDto.

    Attributes:
        position_ticks (Union[Unset, int]): Gets or sets the position ticks.
    """

    position_ticks: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        position_ticks = self.position_ticks

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if position_ticks is not UNSET:
            field_dict["PositionTicks"] = position_ticks

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        position_ticks = d.pop("PositionTicks", UNSET)

        seek_request_dto = cls(
            position_ticks=position_ticks,
        )

        return seek_request_dto



import datetime
from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="UtcTimeResponse")


@_attrs_define
class UtcTimeResponse:
    """Class UtcTimeResponse.

    Attributes:
        request_reception_time (Union[Unset, datetime.datetime]): Gets the UTC time when request has been received.
        response_transmission_time (Union[Unset, datetime.datetime]): Gets the UTC time when response has been sent.
    """

    request_reception_time: Union[Unset, datetime.datetime] = UNSET
    response_transmission_time: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        request_reception_time: Union[Unset, str] = UNSET
        if not isinstance(self.request_reception_time, Unset):
            request_reception_time = self.request_reception_time.isoformat()

        response_transmission_time: Union[Unset, str] = UNSET
        if not isinstance(self.response_transmission_time, Unset):
            response_transmission_time = self.response_transmission_time.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if request_reception_time is not UNSET:
            field_dict["RequestReceptionTime"] = request_reception_time
        if response_transmission_time is not UNSET:
            field_dict["ResponseTransmissionTime"] = response_transmission_time

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _request_reception_time = d.pop("RequestReceptionTime", UNSET)
        request_reception_time: Union[Unset, datetime.datetime]
        if isinstance(_request_reception_time, Unset):
            request_reception_time = UNSET
        else:
            request_reception_time = isoparse(_request_reception_time)

        _response_transmission_time = d.pop("ResponseTransmissionTime", UNSET)
        response_transmission_time: Union[Unset, datetime.datetime]
        if isinstance(_response_transmission_time, Unset):
            response_transmission_time = UNSET
        else:
            response_transmission_time = isoparse(_response_transmission_time)

        utc_time_response = cls(
            request_reception_time=request_reception_time,
            response_transmission_time=response_transmission_time,
        )

        return utc_time_response



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.encoding_context import EncodingContext
from ...models.head_video_stream_stream_options import HeadVideoStreamStreamOptions
from ...models.subtitle_delivery_method import SubtitleDeliveryMethod
from ...types import UNSET, Response, Unset


def _get_kwargs(
    item_id: str,
    *,
    container: Union[Unset, None, str] = UNSET,
    static: Union[Unset, None, bool] = UNSET,
    params: Union[Unset, None, str] = UNSET,
    tag: Union[Unset, None, str] = UNSET,
    device_profile_id: Union[Unset, None, str] = UNSET,
    play_session_id: Union[Unset, None, str] = UNSET,
    segment_container: Union[Unset, None, str] = UNSET,
    segment_length: Union[Unset, None, int] = UNSET,
    min_segments: Union[Unset, None, int] = UNSET,
    media_source_id: Union[Unset, None, str] = UNSET,
    device_id: Union[Unset, None, str] = UNSET,
    audio_codec: Union[Unset, None, str] = UNSET,
    enable_auto_stream_copy: Union[Unset, None, bool] = UNSET,
    allow_video_stream_copy: Union[Unset, None, bool] = UNSET,
    allow_audio_stream_copy: Union[Unset, None, bool] = UNSET,
    break_on_non_key_frames: Union[Unset, None, bool] = UNSET,
    audio_sample_rate: Union[Unset, None, int] = UNSET,
    max_audio_bit_depth: Union[Unset, None, int] = UNSET,
    audio_bit_rate: Union[Unset, None, int] = UNSET,
    audio_channels: Union[Unset, None, int] = UNSET,
    max_audio_channels: Union[Unset, None, int] = UNSET,
    profile: Union[Unset, None, str] = UNSET,
    level: Union[Unset, None, str] = UNSET,
    framerate: Union[Unset, None, float] = UNSET,
    max_framerate: Union[Unset, None, float] = UNSET,
    copy_timestamps: Union[Unset, None, bool] = UNSET,
    start_time_ticks: Union[Unset, None, int] = UNSET,
    width: Union[Unset, None, int] = UNSET,
    height: Union[Unset, None, int] = UNSET,
    max_width: Union[Unset, None, int] = UNSET,
    max_height: Union[Unset, None, int] = UNSET,
    video_bit_rate: Union[Unset, None, int] = UNSET,
    subtitle_stream_index: Union[Unset, None, int] = UNSET,
    subtitle_method: Union[Unset, None, SubtitleDeliveryMethod] = UNSET,
    max_ref_frames: Union[Unset, None, int] = UNSET,
    max_video_bit_depth: Union[Unset, None, int] = UNSET,
    require_avc: Union[Unset, None, bool] = UNSET,
    de_interlace: Union[Unset, None, bool] = UNSET,
    require_non_anamorphic: Union[Unset, None, bool] = UNSET,
    transcoding_max_audio_channels: Union[Unset, None, int] = UNSET,
    cpu_core_limit: Union[Unset, None, int] = UNSET,
    live_stream_id: Union[Unset, None, str] = UNSET,
    enable_mpegts_m2_ts_mode: Union[Unset, None, bool] = UNSET,
    video_codec: Union[Unset, None, str] = UNSET,
    subtitle_codec: Union[Unset, None, str] = UNSET,
    transcode_reasons: Union[Unset, None, str] = UNSET,
    audio_stream_index: Union[Unset, None, int] = UNSET,
    video_stream_index: Union[Unset, None, int] = UNSET,
    context: Union[Unset, None, EncodingContext] = UNSET,
    stream_options: Union[Unset, None, "HeadVideoStreamStreamOptions"] = UNSET,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    params["container"] = container

    params["static"] = static

    params["params"] = params

    params["tag"] = tag

    params["deviceProfileId"] = device_profile_id

    params["playSessionId"] = play_session_id

    params["segmentContainer"] = segment_container

    params["segmentLength"] = segment_length

    params["minSegments"] = min_segments

    params["mediaSourceId"] = media_source_id

    params["deviceId"] = device_id

    params["audioCodec"] = audio_codec

    params["enableAutoStreamCopy"] = enable_auto_stream_copy

    params["allowVideoStreamCopy"] = allow_video_stream_copy

    params["allowAudioStreamCopy"] = allow_audio_stream_copy

    params["breakOnNonKeyFrames"] = break_on_non_key_frames

    params["audioSampleRate"] = audio_sample_rate

    params["maxAudioBitDepth"] = max_audio_bit_depth

    params["audioBitRate"] = audio_bit_rate

    params["audioChannels"] = audio_channels

    params["maxAudioChannels"] = max_audio_channels

    params["profile"] = profile

    params["level"] = level

    params["framerate"] = framerate

    params["maxFramerate"] = max_framerate

    params["copyTimestamps"] = copy_timestamps

    params["startTimeTicks"] = start_time_ticks

    params["width"] = width

    params["height"] = height

    params["maxWidth"] = max_width

    params["maxHeight"] = max_height

    params["videoBitRate"] = video_bit_rate

    params["subtitleStreamIndex"] = subtitle_stream_index

    json_subtitle_method: Union[Unset, None, str] = UNSET
    if not isinstance(subtitle_method, Unset):
        json_subtitle_method = subtitle_method.value if subtitle_method else None

    params["subtitleMethod"] = json_subtitle_method

    params["maxRefFrames"] = max_ref_frames

    params["maxVideoBitDepth"] = max_video_bit_depth

    params["requireAvc"] = require_avc

    params["deInterlace"] = de_interlace

    params["requireNonAnamorphic"] = require_non_anamorphic

    params["transcodingMaxAudioChannels"] = transcoding_max_audio_channels

    params["cpuCoreLimit"] = cpu_core_limit

    params["liveStreamId"] = live_stream_id

    params["enableMpegtsM2TsMode"] = enable_mpegts_m2_ts_mode

    params["videoCodec"] = video_codec

    params["subtitleCodec"] = subtitle_codec

    params["transcodeReasons"] = transcode_reasons

    params["audioStreamIndex"] = audio_stream_index

    params["videoStreamIndex"] = video_stream_index

    json_context: Union[Unset, None, str] = UNSET
    if not isinstance(context, Unset):
        json_context = context.value if context else None

    params["context"] = json_context

    json_stream_options: Union[Unset, None, Dict[str, Any]] = UNSET
    if not isinstance(stream_options, Unset):
        json_stream_options = stream_options.to_dict() if stream_options else None

    if not isinstance(json_stream_options, Unset) and json_stream_options is not None:
        params.update(json_stream_options)

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "head",
        "url": "/Videos/{itemId}/stream".format(
            itemId=item_id,
        ),
        "params": params,
    }


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Any]:
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    item_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    container: Union[Unset, None, str] = UNSET,
    static: Union[Unset, None, bool] = UNSET,
    params: Union[Unset, None, str] = UNSET,
    tag: Union[Unset, None, str] = UNSET,
    device_profile_id: Union[Unset, None, str] = UNSET,
    play_session_id: Union[Unset, None, str] = UNSET,
    segment_container: Union[Unset, None, str] = UNSET,
    segment_length: Union[Unset, None, int] = UNSET,
    min_segments: Union[Unset, None, int] = UNSET,
    media_source_id: Union[Unset, None, str] = UNSET,
    device_id: Union[Unset, None, str] = UNSET,
    audio_codec: Union[Unset, None, str] = UNSET,
    enable_auto_stream_copy: Union[Unset, None, bool] = UNSET,
    allow_video_stream_copy: Union[Unset, None, bool] = UNSET,
    allow_audio_stream_copy: Union[Unset, None, bool] = UNSET,
    break_on_non_key_frames: Union[Unset, None, bool] = UNSET,
    audio_sample_rate: Union[Unset, None, int] = UNSET,
    max_audio_bit_depth: Union[Unset, None, int] = UNSET,
    audio_bit_rate: Union[Unset, None, int] = UNSET,
    audio_channels: Union[Unset, None, int] = UNSET,
    max_audio_channels: Union[Unset, None, int] = UNSET,
    profile: Union[Unset, None, str] = UNSET,
    level: Union[Unset, None, str] = UNSET,
    framerate: Union[Unset, None, float] = UNSET,
    max_framerate: Union[Unset, None, float] = UNSET,
    copy_timestamps: Union[Unset, None, bool] = UNSET,
    start_time_ticks: Union[Unset, None, int] = UNSET,
    width: Union[Unset, None, int] = UNSET,
    height: Union[Unset, None, int] = UNSET,
    max_width: Union[Unset, None, int] = UNSET,
    max_height: Union[Unset, None, int] = UNSET,
    video_bit_rate: Union[Unset, None, int] = UNSET,
    subtitle_stream_index: Union[Unset, None, int] = UNSET,
    subtitle_method: Union[Unset, None, SubtitleDeliveryMethod] = UNSET,
    max_ref_frames: Union[Unset, None, int] = UNSET,
    max_video_bit_depth: Union[Unset, None, int] = UNSET,
    require_avc: Union[Unset, None, bool] = UNSET,
    de_interlace: Union[Unset, None, bool] = UNSET,
    require_non_anamorphic: Union[Unset, None, bool] = UNSET,
    transcoding_max_audio_channels: Union[Unset, None, int] = UNSET,
    cpu_core_limit: Union[Unset, None, int] = UNSET,
    live_stream_id: Union[Unset, None, str] = UNSET,
    enable_mpegts_m2_ts_mode: Union[Unset, None, bool] = UNSET,
    video_codec: Union[Unset, None, str] = UNSET,
    subtitle_codec: Union[Unset, None, str] = UNSET,
    transcode_reasons: Union[Unset, None, str] = UNSET,
    audio_stream_index: Union[Unset, None, int] = UNSET,
    video_stream_index: Union[Unset, None, int] = UNSET,
    context: Union[Unset, None, EncodingContext] = UNSET,
    stream_options: Union[Unset, None, "HeadVideoStreamStreamOptions"] = UNSET,
) -> Response[Any]:
    """Gets a video stream.

    Args:
        item_id (str):
        container (Union[Unset, None, str]):
        static (Union[Unset, None, bool]):
        params (Union[Unset, None, str]):
        tag (Union[Unset, None, str]):
        device_profile_id (Union[Unset, None, str]):
        play_session_id (Union[Unset, None, str]):
        segment_container (Union[Unset, None, str]):
        segment_length (Union[Unset, None, int]):
        min_segments (Union[Unset, None, int]):
        media_source_id (Union[Unset, None, str]):
        device_id (Union[Unset, None, str]):
        audio_codec (Union[Unset, None, str]):
        enable_auto_stream_copy (Union[Unset, None, bool]):
        allow_video_stream_copy (Union[Unset, None, bool]):
        allow_audio_stream_copy (Union[Unset, None, bool]):
        break_on_non_key_frames (Union[Unset, None, bool]):
        audio_sample_rate (Union[Unset, None, int]):
        max_audio_bit_depth (Union[Unset, None, int]):
        audio_bit_rate (Union[Unset, None, int]):
        audio_channels (Union[Unset, None, int]):
        max_audio_channels (Union[Unset, None, int]):
        profile (Union[Unset, None, str]):
        level (Union[Unset, None, str]):
        framerate (Union[Unset, None, float]):
        max_framerate (Union[Unset, None, float]):
        copy_timestamps (Union[Unset, None, bool]):
        start_time_ticks (Union[Unset, None, int]):
        width (Union[Unset, None, int]):
        height (Union[Unset, None, int]):
        max_width (Union[Unset, None, int]):
        max_height (Union[Unset, None, int]):
        video_bit_rate (Union[Unset, None, int]):
        subtitle_stream_index (Union[Unset, None, int]):
        subtitle_method (Union[Unset, None, SubtitleDeliveryMethod]): Delivery method to use
            during playback of a specific subtitle format.
        max_ref_frames (Union[Unset, None, int]):
        max_video_bit_depth (Union[Unset, None, int]):
        require_avc (Union[Unset, None, bool]):
        de_interlace (Union[Unset, None, bool]):
        require_non_anamorphic (Union[Unset, None, bool]):
        transcoding_max_audio_channels (Union[Unset, None, int]):
        cpu_core_limit (Union[Unset, None, int]):
        live_stream_id (Union[Unset, None, str]):
        enable_mpegts_m2_ts_mode (Union[Unset, None, bool]):
        video_codec (Union[Unset, None, str]):
        subtitle_codec (Union[Unset, None, str]):
        transcode_reasons (Union[Unset, None, str]):
        audio_stream_index (Union[Unset, None, int]):
        video_stream_index (Union[Unset, None, int]):
        context (Union[Unset, None, EncodingContext]):
        stream_options (Union[Unset, None, HeadVideoStreamStreamOptions]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        item_id=item_id,
        container=container,
        static=static,
        params=params,
        tag=tag,
        device_profile_id=device_profile_id,
        play_session_id=play_session_id,
        segment_container=segment_container,
        segment_length=segment_length,
        min_segments=min_segments,
        media_source_id=media_source_id,
        device_id=device_id,
        audio_codec=audio_codec,
        enable_auto_stream_copy=enable_auto_stream_copy,
        allow_video_stream_copy=allow_video_stream_copy,
        allow_audio_stream_copy=allow_audio_stream_copy,
        break_on_non_key_frames=break_on_non_key_frames,
        audio_sample_rate=audio_sample_rate,
        max_audio_bit_depth=max_audio_bit_depth,
        audio_bit_rate=audio_bit_rate,
        audio_channels=audio_channels,
        max_audio_channels=max_audio_channels,
        profile=profile,
        level=level,
        framerate=framerate,
        max_framerate=max_framerate,
        copy_timestamps=copy_timestamps,
        start_time_ticks=start_time_ticks,
        width=width,
        height=height,
        max_width=max_width,
        max_height=max_height,
        video_bit_rate=video_bit_rate,
        subtitle_stream_index=subtitle_stream_index,
        subtitle_method=subtitle_method,
        max_ref_frames=max_ref_frames,
        max_video_bit_depth=max_video_bit_depth,
        require_avc=require_avc,
        de_interlace=de_interlace,
        require_non_anamorphic=require_non_anamorphic,
        transcoding_max_audio_channels=transcoding_max_audio_channels,
        cpu_core_limit=cpu_core_limit,
        live_stream_id=live_stream_id,
        enable_mpegts_m2_ts_mode=enable_mpegts_m2_ts_mode,
        video_codec=video_codec,
        subtitle_codec=subtitle_codec,
        transcode_reasons=transcode_reasons,
        audio_stream_index=audio_stream_index,
        video_stream_index=video_stream_index,
        context=context,
        stream_options=stream_options,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    item_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    container: Union[Unset, None, str] = UNSET,
    static: Union[Unset, None, bool] = UNSET,
    params: Union[Unset, None, str] = UNSET,
    tag: Union[Unset, None, str] = UNSET,
    device_profile_id: Union[Unset, None, str] = UNSET,
    play_session_id: Union[Unset, None, str] = UNSET,
    segment_container: Union[Unset, None, str] = UNSET,
    segment_length: Union[Unset, None, int] = UNSET,
    min_segments: Union[Unset, None, int] = UNSET,
    media_source_id: Union[Unset, None, str] = UNSET,
    device_id: Union[Unset, None, str] = UNSET,
    audio_codec: Union[Unset, None, str] = UNSET,
    enable_auto_stream_copy: Union[Unset, None, bool] = UNSET,
    allow_video_stream_copy: Union[Unset, None, bool] = UNSET,
    allow_audio_stream_copy: Union[Unset, None, bool] = UNSET,
    break_on_non_key_frames: Union[Unset, None, bool] = UNSET,
    audio_sample_rate: Union[Unset, None, int] = UNSET,
    max_audio_bit_depth: Union[Unset, None, int] = UNSET,
    audio_bit_rate: Union[Unset, None, int] = UNSET,
    audio_channels: Union[Unset, None, int] = UNSET,
    max_audio_channels: Union[Unset, None, int] = UNSET,
    profile: Union[Unset, None, str] = UNSET,
    level: Union[Unset, None, str] = UNSET,
    framerate: Union[Unset, None, float] = UNSET,
    max_framerate: Union[Unset, None, float] = UNSET,
    copy_timestamps: Union[Unset, None, bool] = UNSET,
    start_time_ticks: Union[Unset, None, int] = UNSET,
    width: Union[Unset, None, int] = UNSET,
    height: Union[Unset, None, int] = UNSET,
    max_width: Union[Unset, None, int] = UNSET,
    max_height: Union[Unset, None, int] = UNSET,
    video_bit_rate: Union[Unset, None, int] = UNSET,
    subtitle_stream_index: Union[Unset, None, int] = UNSET,
    subtitle_method: Union[Unset, None, SubtitleDeliveryMethod] = UNSET,
    max_ref_frames: Union[Unset, None, int] = UNSET,
    max_video_bit_depth: Union[Unset, None, int] = UNSET,
    require_avc: Union[Unset, None, bool] = UNSET,
    de_interlace: Union[Unset, None, bool] = UNSET,
    require_non_anamorphic: Union[Unset, None, bool] = UNSET,
    transcoding_max_audio_channels: Union[Unset, None, int] = UNSET,
    cpu_core_limit: Union[Unset, None, int] = UNSET,
    live_stream_id: Union[Unset, None, str] = UNSET,
    enable_mpegts_m2_ts_mode: Union[Unset, None, bool] = UNSET,
    video_codec: Union[Unset, None, str] = UNSET,
    subtitle_codec: Union[Unset, None, str] = UNSET,
    transcode_reasons: Union[Unset, None, str] = UNSET,
    audio_stream_index: Union[Unset, None, int] = UNSET,
    video_stream_index: Union[Unset, None, int] = UNSET,
    context: Union[Unset, None, EncodingContext] = UNSET,
    stream_options: Union[Unset, None, "HeadVideoStreamStreamOptions"] = UNSET,
) -> Response[Any]:
    """Gets a video stream.

    Args:
        item_id (str):
        container (Union[Unset, None, str]):
        static (Union[Unset, None, bool]):
        params (Union[Unset, None, str]):
        tag (Union[Unset, None, str]):
        device_profile_id (Union[Unset, None, str]):
        play_session_id (Union[Unset, None, str]):
        segment_container (Union[Unset, None, str]):
        segment_length (Union[Unset, None, int]):
        min_segments (Union[Unset, None, int]):
        media_source_id (Union[Unset, None, str]):
        device_id (Union[Unset, None, str]):
        audio_codec (Union[Unset, None, str]):
        enable_auto_stream_copy (Union[Unset, None, bool]):
        allow_video_stream_copy (Union[Unset, None, bool]):
        allow_audio_stream_copy (Union[Unset, None, bool]):
        break_on_non_key_frames (Union[Unset, None, bool]):
        audio_sample_rate (Union[Unset, None, int]):
        max_audio_bit_depth (Union[Unset, None, int]):
        audio_bit_rate (Union[Unset, None, int]):
        audio_channels (Union[Unset, None, int]):
        max_audio_channels (Union[Unset, None, int]):
        profile (Union[Unset, None, str]):
        level (Union[Unset, None, str]):
        framerate (Union[Unset, None, float]):
        max_framerate (Union[Unset, None, float]):
        copy_timestamps (Union[Unset, None, bool]):
        start_time_ticks (Union[Unset, None, int]):
        width (Union[Unset, None, int]):
        height (Union[Unset, None, int]):
        max_width (Union[Unset, None, int]):
        max_height (Union[Unset, None, int]):
        video_bit_rate (Union[Unset, None, int]):
        subtitle_stream_index (Union[Unset, None, int]):
        subtitle_method (Union[Unset, None, SubtitleDeliveryMethod]): Delivery method to use
            during playback of a specific subtitle format.
        max_ref_frames (Union[Unset, None, int]):
        max_video_bit_depth (Union[Unset, None, int]):
        require_avc (Union[Unset, None, bool]):
        de_interlace (Union[Unset, None, bool]):
        require_non_anamorphic (Union[Unset, None, bool]):
        transcoding_max_audio_channels (Union[Unset, None, int]):
        cpu_core_limit (Union[Unset, None, int]):
        live_stream_id (Union[Unset, None, str]):
        enable_mpegts_m2_ts_mode (Union[Unset, None, bool]):
        video_codec (Union[Unset, None, str]):
        subtitle_codec (Union[Unset, None, str]):
        transcode_reasons (Union[Unset, None, str]):
        audio_stream_index (Union[Unset, None, int]):
        video_stream_index (Union[Unset, None, int]):
        context (Union[Unset, None, EncodingContext]):
        stream_options (Union[Unset, None, HeadVideoStreamStreamOptions]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        item_id=item_id,
        container=container,
        static=static,
        params=params,
        tag=tag,
        device_profile_id=device_profile_id,
        play_session_id=play_session_id,
        segment_container=segment_container,
        segment_length=segment_length,
        min_segments=min_segments,
        media_source_id=media_source_id,
        device_id=device_id,
        audio_codec=audio_codec,
        enable_auto_stream_copy=enable_auto_stream_copy,
        allow_video_stream_copy=allow_video_stream_copy,
        allow_audio_stream_copy=allow_audio_stream_copy,
        break_on_non_key_frames=break_on_non_key_frames,
        audio_sample_rate=audio_sample_rate,
        max_audio_bit_depth=max_audio_bit_depth,
        audio_bit_rate=audio_bit_rate,
        audio_channels=audio_channels,
        max_audio_channels=max_audio_channels,
        profile=profile,
        level=level,
        framerate=framerate,
        max_framerate=max_framerate,
        copy_timestamps=copy_timestamps,
        start_time_ticks=start_time_ticks,
        width=width,
        height=height,
        max_width=max_width,
        max_height=max_height,
        video_bit_rate=video_bit_rate,
        subtitle_stream_index=subtitle_stream_index,
        subtitle_method=subtitle_method,
        max_ref_frames=max_ref_frames,
        max_video_bit_depth=max_video_bit_depth,
        require_avc=require_avc,
        de_interlace=de_interlace,
        require_non_anamorphic=require_non_anamorphic,
        transcoding_max_audio_channels=transcoding_max_audio_channels,
        cpu_core_limit=cpu_core_limit,
        live_stream_id=live_stream_id,
        enable_mpegts_m2_ts_mode=enable_mpegts_m2_ts_mode,
        video_codec=video_codec,
        subtitle_codec=subtitle_codec,
        transcode_reasons=transcode_reasons,
        audio_stream_index=audio_stream_index,
        video_stream_index=video_stream_index,
        context=context,
        stream_options=stream_options,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.notification_dto import NotificationDto


T = TypeVar("T", bound="NotificationResultDto")


@_attrs_define
class NotificationResultDto:
    """A list of notifications with the total record count for pagination.

    Attributes:
        notifications (Union[Unset, List['NotificationDto']]): Gets or sets the current page of notifications.
        total_record_count (Union[Unset, int]): Gets or sets the total number of notifications.
    """

    notifications: Union[Unset, List["NotificationDto"]] = UNSET
    total_record_count: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        notifications: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.notifications, Unset):
            notifications = []
            for notifications_item_data in self.notifications:
                notifications_item = notifications_item_data.to_dict()

                notifications.append(notifications_item)

        total_record_count = self.total_record_count

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if notifications is not UNSET:
            field_dict["Notifications"] = notifications
        if total_record_count is not UNSET:
            field_dict["TotalRecordCount"] = total_record_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.notification_dto import NotificationDto

        d = src_dict.copy()
        notifications = []
        _notifications = d.pop("Notifications", UNSET)
        for notifications_item_data in _notifications or []:
            notifications_item = NotificationDto.from_dict(notifications_item_data)

            notifications.append(notifications_item)

        total_record_count = d.pop("TotalRecordCount", UNSET)

        notification_result_dto = cls(
            notifications=notifications,
            total_record_count=total_record_count,
        )

        return notification_result_dto



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="EndPointInfo")


@_attrs_define
class EndPointInfo:
    """
    Attributes:
        is_local (Union[Unset, bool]):
        is_in_network (Union[Unset, bool]):
    """

    is_local: Union[Unset, bool] = UNSET
    is_in_network: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        is_local = self.is_local
        is_in_network = self.is_in_network

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if is_local is not UNSET:
            field_dict["IsLocal"] = is_local
        if is_in_network is not UNSET:
            field_dict["IsInNetwork"] = is_in_network

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        is_local = d.pop("IsLocal", UNSET)

        is_in_network = d.pop("IsInNetwork", UNSET)

        end_point_info = cls(
            is_local=is_local,
            is_in_network=is_in_network,
        )

        return end_point_info



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="MediaPathInfo")


@_attrs_define
class MediaPathInfo:
    """
    Attributes:
        path (Union[Unset, str]):
        network_path (Union[Unset, None, str]):
    """

    path: Union[Unset, str] = UNSET
    network_path: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        path = self.path
        network_path = self.network_path

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if path is not UNSET:
            field_dict["Path"] = path
        if network_path is not UNSET:
            field_dict["NetworkPath"] = network_path

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        path = d.pop("Path", UNSET)

        network_path = d.pop("NetworkPath", UNSET)

        media_path_info = cls(
            path=path,
            network_path=network_path,
        )

        return media_path_info



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="WakeOnLanInfo")


@_attrs_define
class WakeOnLanInfo:
    """Provides the MAC address and port for wake-on-LAN functionality.

    Attributes:
        mac_address (Union[Unset, None, str]): Gets the MAC address of the device.
        port (Union[Unset, int]): Gets or sets the wake-on-LAN port.
    """

    mac_address: Union[Unset, None, str] = UNSET
    port: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        mac_address = self.mac_address
        port = self.port

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if mac_address is not UNSET:
            field_dict["MacAddress"] = mac_address
        if port is not UNSET:
            field_dict["Port"] = port

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        mac_address = d.pop("MacAddress", UNSET)

        port = d.pop("Port", UNSET)

        wake_on_lan_info = cls(
            mac_address=mac_address,
            port=port,
        )

        return wake_on_lan_info



from enum import Enum


class TranscodeReason(str, Enum):
    ANAMORPHICVIDEONOTSUPPORTED = "AnamorphicVideoNotSupported"
    AUDIOBITDEPTHNOTSUPPORTED = "AudioBitDepthNotSupported"
    AUDIOBITRATENOTSUPPORTED = "AudioBitrateNotSupported"
    AUDIOCHANNELSNOTSUPPORTED = "AudioChannelsNotSupported"
    AUDIOCODECNOTSUPPORTED = "AudioCodecNotSupported"
    AUDIOISEXTERNAL = "AudioIsExternal"
    AUDIOPROFILENOTSUPPORTED = "AudioProfileNotSupported"
    AUDIOSAMPLERATENOTSUPPORTED = "AudioSampleRateNotSupported"
    CONTAINERBITRATEEXCEEDSLIMIT = "ContainerBitrateExceedsLimit"
    CONTAINERNOTSUPPORTED = "ContainerNotSupported"
    DIRECTPLAYERROR = "DirectPlayError"
    INTERLACEDVIDEONOTSUPPORTED = "InterlacedVideoNotSupported"
    REFFRAMESNOTSUPPORTED = "RefFramesNotSupported"
    SECONDARYAUDIONOTSUPPORTED = "SecondaryAudioNotSupported"
    SUBTITLECODECNOTSUPPORTED = "SubtitleCodecNotSupported"
    UNKNOWNAUDIOSTREAMINFO = "UnknownAudioStreamInfo"
    UNKNOWNVIDEOSTREAMINFO = "UnknownVideoStreamInfo"
    VIDEOBITDEPTHNOTSUPPORTED = "VideoBitDepthNotSupported"
    VIDEOBITRATENOTSUPPORTED = "VideoBitrateNotSupported"
    VIDEOCODECNOTSUPPORTED = "VideoCodecNotSupported"
    VIDEOFRAMERATENOTSUPPORTED = "VideoFramerateNotSupported"
    VIDEOLEVELNOTSUPPORTED = "VideoLevelNotSupported"
    VIDEOPROFILENOTSUPPORTED = "VideoProfileNotSupported"
    VIDEORANGETYPENOTSUPPORTED = "VideoRangeTypeNotSupported"
    VIDEORESOLUTIONNOTSUPPORTED = "VideoResolutionNotSupported"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="IgnoreWaitRequestDto")


@_attrs_define
class IgnoreWaitRequestDto:
    """Class IgnoreWaitRequestDto.

    Attributes:
        ignore_wait (Union[Unset, bool]): Gets or sets a value indicating whether the client should be ignored.
    """

    ignore_wait: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        ignore_wait = self.ignore_wait

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if ignore_wait is not UNSET:
            field_dict["IgnoreWait"] = ignore_wait

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        ignore_wait = d.pop("IgnoreWait", UNSET)

        ignore_wait_request_dto = cls(
            ignore_wait=ignore_wait,
        )

        return ignore_wait_request_dto



from enum import Enum


class GeneralCommandType(str, Enum):
    BACK = "Back"
    CHANNELDOWN = "ChannelDown"
    CHANNELUP = "ChannelUp"
    DISPLAYCONTENT = "DisplayContent"
    DISPLAYMESSAGE = "DisplayMessage"
    GOHOME = "GoHome"
    GOTOSEARCH = "GoToSearch"
    GOTOSETTINGS = "GoToSettings"
    GUIDE = "Guide"
    MOVEDOWN = "MoveDown"
    MOVELEFT = "MoveLeft"
    MOVERIGHT = "MoveRight"
    MOVEUP = "MoveUp"
    MUTE = "Mute"
    NEXTLETTER = "NextLetter"
    PAGEDOWN = "PageDown"
    PAGEUP = "PageUp"
    PLAY = "Play"
    PLAYMEDIASOURCE = "PlayMediaSource"
    PLAYNEXT = "PlayNext"
    PLAYSTATE = "PlayState"
    PLAYTRAILERS = "PlayTrailers"
    PREVIOUSLETTER = "PreviousLetter"
    SELECT = "Select"
    SENDKEY = "SendKey"
    SENDSTRING = "SendString"
    SETAUDIOSTREAMINDEX = "SetAudioStreamIndex"
    SETMAXSTREAMINGBITRATE = "SetMaxStreamingBitrate"
    SETREPEATMODE = "SetRepeatMode"
    SETSHUFFLEQUEUE = "SetShuffleQueue"
    SETSUBTITLESTREAMINDEX = "SetSubtitleStreamIndex"
    SETVOLUME = "SetVolume"
    TAKESCREENSHOT = "TakeScreenshot"
    TOGGLECONTEXTMENU = "ToggleContextMenu"
    TOGGLEFULLSCREEN = "ToggleFullscreen"
    TOGGLEMUTE = "ToggleMute"
    TOGGLEOSD = "ToggleOsd"
    TOGGLEOSDMENU = "ToggleOsdMenu"
    TOGGLESTATS = "ToggleStats"
    UNMUTE = "Unmute"
    VOLUMEDOWN = "VolumeDown"
    VOLUMEUP = "VolumeUp"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.iso_type import IsoType
from ..models.media_protocol import MediaProtocol
from ..models.media_source_type import MediaSourceType
from ..models.transport_stream_timestamp import TransportStreamTimestamp
from ..models.video_3d_format import Video3DFormat
from ..models.video_type import VideoType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.media_attachment import MediaAttachment
    from ..models.media_source_info_required_http_headers import MediaSourceInfoRequiredHttpHeaders
    from ..models.media_stream import MediaStream


T = TypeVar("T", bound="MediaSourceInfo")


@_attrs_define
class MediaSourceInfo:
    """
    Attributes:
        protocol (Union[Unset, MediaProtocol]):
        id (Union[Unset, None, str]):
        path (Union[Unset, None, str]):
        encoder_path (Union[Unset, None, str]):
        encoder_protocol (Union[Unset, None, MediaProtocol]):
        type (Union[Unset, MediaSourceType]):
        container (Union[Unset, None, str]):
        size (Union[Unset, None, int]):
        name (Union[Unset, None, str]):
        is_remote (Union[Unset, bool]): Gets or sets a value indicating whether the media is remote.
            Differentiate internet url vs local network.
        e_tag (Union[Unset, None, str]):
        run_time_ticks (Union[Unset, None, int]):
        read_at_native_framerate (Union[Unset, bool]):
        ignore_dts (Union[Unset, bool]):
        ignore_index (Union[Unset, bool]):
        gen_pts_input (Union[Unset, bool]):
        supports_transcoding (Union[Unset, bool]):
        supports_direct_stream (Union[Unset, bool]):
        supports_direct_play (Union[Unset, bool]):
        is_infinite_stream (Union[Unset, bool]):
        requires_opening (Union[Unset, bool]):
        open_token (Union[Unset, None, str]):
        requires_closing (Union[Unset, bool]):
        live_stream_id (Union[Unset, None, str]):
        buffer_ms (Union[Unset, None, int]):
        requires_looping (Union[Unset, bool]):
        supports_probing (Union[Unset, bool]):
        video_type (Union[Unset, None, VideoType]): Enum VideoType.
        iso_type (Union[Unset, None, IsoType]): Enum IsoType.
        video_3d_format (Union[Unset, None, Video3DFormat]):
        media_streams (Union[Unset, None, List['MediaStream']]):
        media_attachments (Union[Unset, None, List['MediaAttachment']]):
        formats (Union[Unset, None, List[str]]):
        bitrate (Union[Unset, None, int]):
        timestamp (Union[Unset, None, TransportStreamTimestamp]):
        required_http_headers (Union[Unset, None, MediaSourceInfoRequiredHttpHeaders]):
        transcoding_url (Union[Unset, None, str]):
        transcoding_sub_protocol (Union[Unset, None, str]):
        transcoding_container (Union[Unset, None, str]):
        analyze_duration_ms (Union[Unset, None, int]):
        default_audio_stream_index (Union[Unset, None, int]):
        default_subtitle_stream_index (Union[Unset, None, int]):
    """

    protocol: Union[Unset, MediaProtocol] = UNSET
    id: Union[Unset, None, str] = UNSET
    path: Union[Unset, None, str] = UNSET
    encoder_path: Union[Unset, None, str] = UNSET
    encoder_protocol: Union[Unset, None, MediaProtocol] = UNSET
    type: Union[Unset, MediaSourceType] = UNSET
    container: Union[Unset, None, str] = UNSET
    size: Union[Unset, None, int] = UNSET
    name: Union[Unset, None, str] = UNSET
    is_remote: Union[Unset, bool] = UNSET
    e_tag: Union[Unset, None, str] = UNSET
    run_time_ticks: Union[Unset, None, int] = UNSET
    read_at_native_framerate: Union[Unset, bool] = UNSET
    ignore_dts: Union[Unset, bool] = UNSET
    ignore_index: Union[Unset, bool] = UNSET
    gen_pts_input: Union[Unset, bool] = UNSET
    supports_transcoding: Union[Unset, bool] = UNSET
    supports_direct_stream: Union[Unset, bool] = UNSET
    supports_direct_play: Union[Unset, bool] = UNSET
    is_infinite_stream: Union[Unset, bool] = UNSET
    requires_opening: Union[Unset, bool] = UNSET
    open_token: Union[Unset, None, str] = UNSET
    requires_closing: Union[Unset, bool] = UNSET
    live_stream_id: Union[Unset, None, str] = UNSET
    buffer_ms: Union[Unset, None, int] = UNSET
    requires_looping: Union[Unset, bool] = UNSET
    supports_probing: Union[Unset, bool] = UNSET
    video_type: Union[Unset, None, VideoType] = UNSET
    iso_type: Union[Unset, None, IsoType] = UNSET
    video_3d_format: Union[Unset, None, Video3DFormat] = UNSET
    media_streams: Union[Unset, None, List["MediaStream"]] = UNSET
    media_attachments: Union[Unset, None, List["MediaAttachment"]] = UNSET
    formats: Union[Unset, None, List[str]] = UNSET
    bitrate: Union[Unset, None, int] = UNSET
    timestamp: Union[Unset, None, TransportStreamTimestamp] = UNSET
    required_http_headers: Union[Unset, None, "MediaSourceInfoRequiredHttpHeaders"] = UNSET
    transcoding_url: Union[Unset, None, str] = UNSET
    transcoding_sub_protocol: Union[Unset, None, str] = UNSET
    transcoding_container: Union[Unset, None, str] = UNSET
    analyze_duration_ms: Union[Unset, None, int] = UNSET
    default_audio_stream_index: Union[Unset, None, int] = UNSET
    default_subtitle_stream_index: Union[Unset, None, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        protocol: Union[Unset, str] = UNSET
        if not isinstance(self.protocol, Unset):
            protocol = self.protocol.value

        id = self.id
        path = self.path
        encoder_path = self.encoder_path
        encoder_protocol: Union[Unset, None, str] = UNSET
        if not isinstance(self.encoder_protocol, Unset):
            encoder_protocol = self.encoder_protocol.value if self.encoder_protocol else None

        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        container = self.container
        size = self.size
        name = self.name
        is_remote = self.is_remote
        e_tag = self.e_tag
        run_time_ticks = self.run_time_ticks
        read_at_native_framerate = self.read_at_native_framerate
        ignore_dts = self.ignore_dts
        ignore_index = self.ignore_index
        gen_pts_input = self.gen_pts_input
        supports_transcoding = self.supports_transcoding
        supports_direct_stream = self.supports_direct_stream
        supports_direct_play = self.supports_direct_play
        is_infinite_stream = self.is_infinite_stream
        requires_opening = self.requires_opening
        open_token = self.open_token
        requires_closing = self.requires_closing
        live_stream_id = self.live_stream_id
        buffer_ms = self.buffer_ms
        requires_looping = self.requires_looping
        supports_probing = self.supports_probing
        video_type: Union[Unset, None, str] = UNSET
        if not isinstance(self.video_type, Unset):
            video_type = self.video_type.value if self.video_type else None

        iso_type: Union[Unset, None, str] = UNSET
        if not isinstance(self.iso_type, Unset):
            iso_type = self.iso_type.value if self.iso_type else None

        video_3d_format: Union[Unset, None, str] = UNSET
        if not isinstance(self.video_3d_format, Unset):
            video_3d_format = self.video_3d_format.value if self.video_3d_format else None

        media_streams: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.media_streams, Unset):
            if self.media_streams is None:
                media_streams = None
            else:
                media_streams = []
                for media_streams_item_data in self.media_streams:
                    media_streams_item = media_streams_item_data.to_dict()

                    media_streams.append(media_streams_item)

        media_attachments: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.media_attachments, Unset):
            if self.media_attachments is None:
                media_attachments = None
            else:
                media_attachments = []
                for media_attachments_item_data in self.media_attachments:
                    media_attachments_item = media_attachments_item_data.to_dict()

                    media_attachments.append(media_attachments_item)

        formats: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.formats, Unset):
            if self.formats is None:
                formats = None
            else:
                formats = self.formats

        bitrate = self.bitrate
        timestamp: Union[Unset, None, str] = UNSET
        if not isinstance(self.timestamp, Unset):
            timestamp = self.timestamp.value if self.timestamp else None

        required_http_headers: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.required_http_headers, Unset):
            required_http_headers = self.required_http_headers.to_dict() if self.required_http_headers else None

        transcoding_url = self.transcoding_url
        transcoding_sub_protocol = self.transcoding_sub_protocol
        transcoding_container = self.transcoding_container
        analyze_duration_ms = self.analyze_duration_ms
        default_audio_stream_index = self.default_audio_stream_index
        default_subtitle_stream_index = self.default_subtitle_stream_index

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if protocol is not UNSET:
            field_dict["Protocol"] = protocol
        if id is not UNSET:
            field_dict["Id"] = id
        if path is not UNSET:
            field_dict["Path"] = path
        if encoder_path is not UNSET:
            field_dict["EncoderPath"] = encoder_path
        if encoder_protocol is not UNSET:
            field_dict["EncoderProtocol"] = encoder_protocol
        if type is not UNSET:
            field_dict["Type"] = type
        if container is not UNSET:
            field_dict["Container"] = container
        if size is not UNSET:
            field_dict["Size"] = size
        if name is not UNSET:
            field_dict["Name"] = name
        if is_remote is not UNSET:
            field_dict["IsRemote"] = is_remote
        if e_tag is not UNSET:
            field_dict["ETag"] = e_tag
        if run_time_ticks is not UNSET:
            field_dict["RunTimeTicks"] = run_time_ticks
        if read_at_native_framerate is not UNSET:
            field_dict["ReadAtNativeFramerate"] = read_at_native_framerate
        if ignore_dts is not UNSET:
            field_dict["IgnoreDts"] = ignore_dts
        if ignore_index is not UNSET:
            field_dict["IgnoreIndex"] = ignore_index
        if gen_pts_input is not UNSET:
            field_dict["GenPtsInput"] = gen_pts_input
        if supports_transcoding is not UNSET:
            field_dict["SupportsTranscoding"] = supports_transcoding
        if supports_direct_stream is not UNSET:
            field_dict["SupportsDirectStream"] = supports_direct_stream
        if supports_direct_play is not UNSET:
            field_dict["SupportsDirectPlay"] = supports_direct_play
        if is_infinite_stream is not UNSET:
            field_dict["IsInfiniteStream"] = is_infinite_stream
        if requires_opening is not UNSET:
            field_dict["RequiresOpening"] = requires_opening
        if open_token is not UNSET:
            field_dict["OpenToken"] = open_token
        if requires_closing is not UNSET:
            field_dict["RequiresClosing"] = requires_closing
        if live_stream_id is not UNSET:
            field_dict["LiveStreamId"] = live_stream_id
        if buffer_ms is not UNSET:
            field_dict["BufferMs"] = buffer_ms
        if requires_looping is not UNSET:
            field_dict["RequiresLooping"] = requires_looping
        if supports_probing is not UNSET:
            field_dict["SupportsProbing"] = supports_probing
        if video_type is not UNSET:
            field_dict["VideoType"] = video_type
        if iso_type is not UNSET:
            field_dict["IsoType"] = iso_type
        if video_3d_format is not UNSET:
            field_dict["Video3DFormat"] = video_3d_format
        if media_streams is not UNSET:
            field_dict["MediaStreams"] = media_streams
        if media_attachments is not UNSET:
            field_dict["MediaAttachments"] = media_attachments
        if formats is not UNSET:
            field_dict["Formats"] = formats
        if bitrate is not UNSET:
            field_dict["Bitrate"] = bitrate
        if timestamp is not UNSET:
            field_dict["Timestamp"] = timestamp
        if required_http_headers is not UNSET:
            field_dict["RequiredHttpHeaders"] = required_http_headers
        if transcoding_url is not UNSET:
            field_dict["TranscodingUrl"] = transcoding_url
        if transcoding_sub_protocol is not UNSET:
            field_dict["TranscodingSubProtocol"] = transcoding_sub_protocol
        if transcoding_container is not UNSET:
            field_dict["TranscodingContainer"] = transcoding_container
        if analyze_duration_ms is not UNSET:
            field_dict["AnalyzeDurationMs"] = analyze_duration_ms
        if default_audio_stream_index is not UNSET:
            field_dict["DefaultAudioStreamIndex"] = default_audio_stream_index
        if default_subtitle_stream_index is not UNSET:
            field_dict["DefaultSubtitleStreamIndex"] = default_subtitle_stream_index

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.media_attachment import MediaAttachment
        from ..models.media_source_info_required_http_headers import MediaSourceInfoRequiredHttpHeaders
        from ..models.media_stream import MediaStream

        d = src_dict.copy()
        _protocol = d.pop("Protocol", UNSET)
        protocol: Union[Unset, MediaProtocol]
        if isinstance(_protocol, Unset):
            protocol = UNSET
        else:
            protocol = MediaProtocol(_protocol)

        id = d.pop("Id", UNSET)

        path = d.pop("Path", UNSET)

        encoder_path = d.pop("EncoderPath", UNSET)

        _encoder_protocol = d.pop("EncoderProtocol", UNSET)
        encoder_protocol: Union[Unset, None, MediaProtocol]
        if _encoder_protocol is None:
            encoder_protocol = None
        elif isinstance(_encoder_protocol, Unset):
            encoder_protocol = UNSET
        else:
            encoder_protocol = MediaProtocol(_encoder_protocol)

        _type = d.pop("Type", UNSET)
        type: Union[Unset, MediaSourceType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = MediaSourceType(_type)

        container = d.pop("Container", UNSET)

        size = d.pop("Size", UNSET)

        name = d.pop("Name", UNSET)

        is_remote = d.pop("IsRemote", UNSET)

        e_tag = d.pop("ETag", UNSET)

        run_time_ticks = d.pop("RunTimeTicks", UNSET)

        read_at_native_framerate = d.pop("ReadAtNativeFramerate", UNSET)

        ignore_dts = d.pop("IgnoreDts", UNSET)

        ignore_index = d.pop("IgnoreIndex", UNSET)

        gen_pts_input = d.pop("GenPtsInput", UNSET)

        supports_transcoding = d.pop("SupportsTranscoding", UNSET)

        supports_direct_stream = d.pop("SupportsDirectStream", UNSET)

        supports_direct_play = d.pop("SupportsDirectPlay", UNSET)

        is_infinite_stream = d.pop("IsInfiniteStream", UNSET)

        requires_opening = d.pop("RequiresOpening", UNSET)

        open_token = d.pop("OpenToken", UNSET)

        requires_closing = d.pop("RequiresClosing", UNSET)

        live_stream_id = d.pop("LiveStreamId", UNSET)

        buffer_ms = d.pop("BufferMs", UNSET)

        requires_looping = d.pop("RequiresLooping", UNSET)

        supports_probing = d.pop("SupportsProbing", UNSET)

        _video_type = d.pop("VideoType", UNSET)
        video_type: Union[Unset, None, VideoType]
        if _video_type is None:
            video_type = None
        elif isinstance(_video_type, Unset):
            video_type = UNSET
        else:
            video_type = VideoType(_video_type)

        _iso_type = d.pop("IsoType", UNSET)
        iso_type: Union[Unset, None, IsoType]
        if _iso_type is None:
            iso_type = None
        elif isinstance(_iso_type, Unset):
            iso_type = UNSET
        else:
            iso_type = IsoType(_iso_type)

        _video_3d_format = d.pop("Video3DFormat", UNSET)
        video_3d_format: Union[Unset, None, Video3DFormat]
        if _video_3d_format is None:
            video_3d_format = None
        elif isinstance(_video_3d_format, Unset):
            video_3d_format = UNSET
        else:
            video_3d_format = Video3DFormat(_video_3d_format)

        media_streams = []
        _media_streams = d.pop("MediaStreams", UNSET)
        for media_streams_item_data in _media_streams or []:
            media_streams_item = MediaStream.from_dict(media_streams_item_data)

            media_streams.append(media_streams_item)

        media_attachments = []
        _media_attachments = d.pop("MediaAttachments", UNSET)
        for media_attachments_item_data in _media_attachments or []:
            media_attachments_item = MediaAttachment.from_dict(media_attachments_item_data)

            media_attachments.append(media_attachments_item)

        formats = cast(List[str], d.pop("Formats", UNSET))

        bitrate = d.pop("Bitrate", UNSET)

        _timestamp = d.pop("Timestamp", UNSET)
        timestamp: Union[Unset, None, TransportStreamTimestamp]
        if _timestamp is None:
            timestamp = None
        elif isinstance(_timestamp, Unset):
            timestamp = UNSET
        else:
            timestamp = TransportStreamTimestamp(_timestamp)

        _required_http_headers = d.pop("RequiredHttpHeaders", UNSET)
        required_http_headers: Union[Unset, None, MediaSourceInfoRequiredHttpHeaders]
        if _required_http_headers is None:
            required_http_headers = None
        elif isinstance(_required_http_headers, Unset):
            required_http_headers = UNSET
        else:
            required_http_headers = MediaSourceInfoRequiredHttpHeaders.from_dict(_required_http_headers)

        transcoding_url = d.pop("TranscodingUrl", UNSET)

        transcoding_sub_protocol = d.pop("TranscodingSubProtocol", UNSET)

        transcoding_container = d.pop("TranscodingContainer", UNSET)

        analyze_duration_ms = d.pop("AnalyzeDurationMs", UNSET)

        default_audio_stream_index = d.pop("DefaultAudioStreamIndex", UNSET)

        default_subtitle_stream_index = d.pop("DefaultSubtitleStreamIndex", UNSET)

        media_source_info = cls(
            protocol=protocol,
            id=id,
            path=path,
            encoder_path=encoder_path,
            encoder_protocol=encoder_protocol,
            type=type,
            container=container,
            size=size,
            name=name,
            is_remote=is_remote,
            e_tag=e_tag,
            run_time_ticks=run_time_ticks,
            read_at_native_framerate=read_at_native_framerate,
            ignore_dts=ignore_dts,
            ignore_index=ignore_index,
            gen_pts_input=gen_pts_input,
            supports_transcoding=supports_transcoding,
            supports_direct_stream=supports_direct_stream,
            supports_direct_play=supports_direct_play,
            is_infinite_stream=is_infinite_stream,
            requires_opening=requires_opening,
            open_token=open_token,
            requires_closing=requires_closing,
            live_stream_id=live_stream_id,
            buffer_ms=buffer_ms,
            requires_looping=requires_looping,
            supports_probing=supports_probing,
            video_type=video_type,
            iso_type=iso_type,
            video_3d_format=video_3d_format,
            media_streams=media_streams,
            media_attachments=media_attachments,
            formats=formats,
            bitrate=bitrate,
            timestamp=timestamp,
            required_http_headers=required_http_headers,
            transcoding_url=transcoding_url,
            transcoding_sub_protocol=transcoding_sub_protocol,
            transcoding_container=transcoding_container,
            analyze_duration_ms=analyze_duration_ms,
            default_audio_stream_index=default_audio_stream_index,
            default_subtitle_stream_index=default_subtitle_stream_index,
        )

        return media_source_info



from enum import Enum


class DayOfWeek(str, Enum):
    FRIDAY = "Friday"
    MONDAY = "Monday"
    SATURDAY = "Saturday"
    SUNDAY = "Sunday"
    THURSDAY = "Thursday"
    TUESDAY = "Tuesday"
    WEDNESDAY = "Wednesday"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.media_path_info import MediaPathInfo


T = TypeVar("T", bound="MediaPathDto")


@_attrs_define
class MediaPathDto:
    """Media Path dto.

    Attributes:
        name (str): Gets or sets the name of the library.
        path (Union[Unset, None, str]): Gets or sets the path to add.
        path_info (Union[Unset, None, MediaPathInfo]):
    """

    name: str
    path: Union[Unset, None, str] = UNSET
    path_info: Union[Unset, None, "MediaPathInfo"] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        path = self.path
        path_info: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.path_info, Unset):
            path_info = self.path_info.to_dict() if self.path_info else None

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "Name": name,
            }
        )
        if path is not UNSET:
            field_dict["Path"] = path
        if path_info is not UNSET:
            field_dict["PathInfo"] = path_info

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.media_path_info import MediaPathInfo

        d = src_dict.copy()
        name = d.pop("Name")

        path = d.pop("Path", UNSET)

        _path_info = d.pop("PathInfo", UNSET)
        path_info: Union[Unset, None, MediaPathInfo]
        if _path_info is None:
            path_info = None
        elif isinstance(_path_info, Unset):
            path_info = UNSET
        else:
            path_info = MediaPathInfo.from_dict(_path_info)

        media_path_dto = cls(
            name=name,
            path=path,
            path_info=path_info,
        )

        return media_path_dto



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.day_of_week import DayOfWeek
from ..models.day_pattern import DayPattern
from ..models.keep_until import KeepUntil
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.series_timer_info_dto_image_tags import SeriesTimerInfoDtoImageTags


T = TypeVar("T", bound="SeriesTimerInfoDto")


@_attrs_define
class SeriesTimerInfoDto:
    """Class SeriesTimerInfoDto.

    Attributes:
        id (Union[Unset, None, str]): Gets or sets the Id of the recording.
        type (Union[Unset, None, str]):
        server_id (Union[Unset, None, str]): Gets or sets the server identifier.
        external_id (Union[Unset, None, str]): Gets or sets the external identifier.
        channel_id (Union[Unset, str]): Gets or sets the channel id of the recording.
        external_channel_id (Union[Unset, None, str]): Gets or sets the external channel identifier.
        channel_name (Union[Unset, None, str]): Gets or sets the channel name of the recording.
        channel_primary_image_tag (Union[Unset, None, str]):
        program_id (Union[Unset, None, str]): Gets or sets the program identifier.
        external_program_id (Union[Unset, None, str]): Gets or sets the external program identifier.
        name (Union[Unset, None, str]): Gets or sets the name of the recording.
        overview (Union[Unset, None, str]): Gets or sets the description of the recording.
        start_date (Union[Unset, datetime.datetime]): Gets or sets the start date of the recording, in UTC.
        end_date (Union[Unset, datetime.datetime]): Gets or sets the end date of the recording, in UTC.
        service_name (Union[Unset, None, str]): Gets or sets the name of the service.
        priority (Union[Unset, int]): Gets or sets the priority.
        pre_padding_seconds (Union[Unset, int]): Gets or sets the pre padding seconds.
        post_padding_seconds (Union[Unset, int]): Gets or sets the post padding seconds.
        is_pre_padding_required (Union[Unset, bool]): Gets or sets a value indicating whether this instance is pre
            padding required.
        parent_backdrop_item_id (Union[Unset, None, str]): Gets or sets the Id of the Parent that has a backdrop if the
            item does not have one.
        parent_backdrop_image_tags (Union[Unset, None, List[str]]): Gets or sets the parent backdrop image tags.
        is_post_padding_required (Union[Unset, bool]): Gets or sets a value indicating whether this instance is post
            padding required.
        keep_until (Union[Unset, KeepUntil]):
        record_any_time (Union[Unset, bool]): Gets or sets a value indicating whether [record any time].
        skip_episodes_in_library (Union[Unset, bool]):
        record_any_channel (Union[Unset, bool]): Gets or sets a value indicating whether [record any channel].
        keep_up_to (Union[Unset, int]):
        record_new_only (Union[Unset, bool]): Gets or sets a value indicating whether [record new only].
        days (Union[Unset, None, List[DayOfWeek]]): Gets or sets the days.
        day_pattern (Union[Unset, None, DayPattern]):
        image_tags (Union[Unset, None, SeriesTimerInfoDtoImageTags]): Gets or sets the image tags.
        parent_thumb_item_id (Union[Unset, None, str]): Gets or sets the parent thumb item id.
        parent_thumb_image_tag (Union[Unset, None, str]): Gets or sets the parent thumb image tag.
        parent_primary_image_item_id (Union[Unset, None, str]): Gets or sets the parent primary image item identifier.
        parent_primary_image_tag (Union[Unset, None, str]): Gets or sets the parent primary image tag.
    """

    id: Union[Unset, None, str] = UNSET
    type: Union[Unset, None, str] = UNSET
    server_id: Union[Unset, None, str] = UNSET
    external_id: Union[Unset, None, str] = UNSET
    channel_id: Union[Unset, str] = UNSET
    external_channel_id: Union[Unset, None, str] = UNSET
    channel_name: Union[Unset, None, str] = UNSET
    channel_primary_image_tag: Union[Unset, None, str] = UNSET
    program_id: Union[Unset, None, str] = UNSET
    external_program_id: Union[Unset, None, str] = UNSET
    name: Union[Unset, None, str] = UNSET
    overview: Union[Unset, None, str] = UNSET
    start_date: Union[Unset, datetime.datetime] = UNSET
    end_date: Union[Unset, datetime.datetime] = UNSET
    service_name: Union[Unset, None, str] = UNSET
    priority: Union[Unset, int] = UNSET
    pre_padding_seconds: Union[Unset, int] = UNSET
    post_padding_seconds: Union[Unset, int] = UNSET
    is_pre_padding_required: Union[Unset, bool] = UNSET
    parent_backdrop_item_id: Union[Unset, None, str] = UNSET
    parent_backdrop_image_tags: Union[Unset, None, List[str]] = UNSET
    is_post_padding_required: Union[Unset, bool] = UNSET
    keep_until: Union[Unset, KeepUntil] = UNSET
    record_any_time: Union[Unset, bool] = UNSET
    skip_episodes_in_library: Union[Unset, bool] = UNSET
    record_any_channel: Union[Unset, bool] = UNSET
    keep_up_to: Union[Unset, int] = UNSET
    record_new_only: Union[Unset, bool] = UNSET
    days: Union[Unset, None, List[DayOfWeek]] = UNSET
    day_pattern: Union[Unset, None, DayPattern] = UNSET
    image_tags: Union[Unset, None, "SeriesTimerInfoDtoImageTags"] = UNSET
    parent_thumb_item_id: Union[Unset, None, str] = UNSET
    parent_thumb_image_tag: Union[Unset, None, str] = UNSET
    parent_primary_image_item_id: Union[Unset, None, str] = UNSET
    parent_primary_image_tag: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        type = self.type
        server_id = self.server_id
        external_id = self.external_id
        channel_id = self.channel_id
        external_channel_id = self.external_channel_id
        channel_name = self.channel_name
        channel_primary_image_tag = self.channel_primary_image_tag
        program_id = self.program_id
        external_program_id = self.external_program_id
        name = self.name
        overview = self.overview
        start_date: Union[Unset, str] = UNSET
        if not isinstance(self.start_date, Unset):
            start_date = self.start_date.isoformat()

        end_date: Union[Unset, str] = UNSET
        if not isinstance(self.end_date, Unset):
            end_date = self.end_date.isoformat()

        service_name = self.service_name
        priority = self.priority
        pre_padding_seconds = self.pre_padding_seconds
        post_padding_seconds = self.post_padding_seconds
        is_pre_padding_required = self.is_pre_padding_required
        parent_backdrop_item_id = self.parent_backdrop_item_id
        parent_backdrop_image_tags: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.parent_backdrop_image_tags, Unset):
            if self.parent_backdrop_image_tags is None:
                parent_backdrop_image_tags = None
            else:
                parent_backdrop_image_tags = self.parent_backdrop_image_tags

        is_post_padding_required = self.is_post_padding_required
        keep_until: Union[Unset, str] = UNSET
        if not isinstance(self.keep_until, Unset):
            keep_until = self.keep_until.value

        record_any_time = self.record_any_time
        skip_episodes_in_library = self.skip_episodes_in_library
        record_any_channel = self.record_any_channel
        keep_up_to = self.keep_up_to
        record_new_only = self.record_new_only
        days: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.days, Unset):
            if self.days is None:
                days = None
            else:
                days = []
                for days_item_data in self.days:
                    days_item = days_item_data.value

                    days.append(days_item)

        day_pattern: Union[Unset, None, str] = UNSET
        if not isinstance(self.day_pattern, Unset):
            day_pattern = self.day_pattern.value if self.day_pattern else None

        image_tags: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.image_tags, Unset):
            image_tags = self.image_tags.to_dict() if self.image_tags else None

        parent_thumb_item_id = self.parent_thumb_item_id
        parent_thumb_image_tag = self.parent_thumb_image_tag
        parent_primary_image_item_id = self.parent_primary_image_item_id
        parent_primary_image_tag = self.parent_primary_image_tag

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if id is not UNSET:
            field_dict["Id"] = id
        if type is not UNSET:
            field_dict["Type"] = type
        if server_id is not UNSET:
            field_dict["ServerId"] = server_id
        if external_id is not UNSET:
            field_dict["ExternalId"] = external_id
        if channel_id is not UNSET:
            field_dict["ChannelId"] = channel_id
        if external_channel_id is not UNSET:
            field_dict["ExternalChannelId"] = external_channel_id
        if channel_name is not UNSET:
            field_dict["ChannelName"] = channel_name
        if channel_primary_image_tag is not UNSET:
            field_dict["ChannelPrimaryImageTag"] = channel_primary_image_tag
        if program_id is not UNSET:
            field_dict["ProgramId"] = program_id
        if external_program_id is not UNSET:
            field_dict["ExternalProgramId"] = external_program_id
        if name is not UNSET:
            field_dict["Name"] = name
        if overview is not UNSET:
            field_dict["Overview"] = overview
        if start_date is not UNSET:
            field_dict["StartDate"] = start_date
        if end_date is not UNSET:
            field_dict["EndDate"] = end_date
        if service_name is not UNSET:
            field_dict["ServiceName"] = service_name
        if priority is not UNSET:
            field_dict["Priority"] = priority
        if pre_padding_seconds is not UNSET:
            field_dict["PrePaddingSeconds"] = pre_padding_seconds
        if post_padding_seconds is not UNSET:
            field_dict["PostPaddingSeconds"] = post_padding_seconds
        if is_pre_padding_required is not UNSET:
            field_dict["IsPrePaddingRequired"] = is_pre_padding_required
        if parent_backdrop_item_id is not UNSET:
            field_dict["ParentBackdropItemId"] = parent_backdrop_item_id
        if parent_backdrop_image_tags is not UNSET:
            field_dict["ParentBackdropImageTags"] = parent_backdrop_image_tags
        if is_post_padding_required is not UNSET:
            field_dict["IsPostPaddingRequired"] = is_post_padding_required
        if keep_until is not UNSET:
            field_dict["KeepUntil"] = keep_until
        if record_any_time is not UNSET:
            field_dict["RecordAnyTime"] = record_any_time
        if skip_episodes_in_library is not UNSET:
            field_dict["SkipEpisodesInLibrary"] = skip_episodes_in_library
        if record_any_channel is not UNSET:
            field_dict["RecordAnyChannel"] = record_any_channel
        if keep_up_to is not UNSET:
            field_dict["KeepUpTo"] = keep_up_to
        if record_new_only is not UNSET:
            field_dict["RecordNewOnly"] = record_new_only
        if days is not UNSET:
            field_dict["Days"] = days
        if day_pattern is not UNSET:
            field_dict["DayPattern"] = day_pattern
        if image_tags is not UNSET:
            field_dict["ImageTags"] = image_tags
        if parent_thumb_item_id is not UNSET:
            field_dict["ParentThumbItemId"] = parent_thumb_item_id
        if parent_thumb_image_tag is not UNSET:
            field_dict["ParentThumbImageTag"] = parent_thumb_image_tag
        if parent_primary_image_item_id is not UNSET:
            field_dict["ParentPrimaryImageItemId"] = parent_primary_image_item_id
        if parent_primary_image_tag is not UNSET:
            field_dict["ParentPrimaryImageTag"] = parent_primary_image_tag

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.series_timer_info_dto_image_tags import SeriesTimerInfoDtoImageTags

        d = src_dict.copy()
        id = d.pop("Id", UNSET)

        type = d.pop("Type", UNSET)

        server_id = d.pop("ServerId", UNSET)

        external_id = d.pop("ExternalId", UNSET)

        channel_id = d.pop("ChannelId", UNSET)

        external_channel_id = d.pop("ExternalChannelId", UNSET)

        channel_name = d.pop("ChannelName", UNSET)

        channel_primary_image_tag = d.pop("ChannelPrimaryImageTag", UNSET)

        program_id = d.pop("ProgramId", UNSET)

        external_program_id = d.pop("ExternalProgramId", UNSET)

        name = d.pop("Name", UNSET)

        overview = d.pop("Overview", UNSET)

        _start_date = d.pop("StartDate", UNSET)
        start_date: Union[Unset, datetime.datetime]
        if isinstance(_start_date, Unset):
            start_date = UNSET
        else:
            start_date = isoparse(_start_date)

        _end_date = d.pop("EndDate", UNSET)
        end_date: Union[Unset, datetime.datetime]
        if isinstance(_end_date, Unset):
            end_date = UNSET
        else:
            end_date = isoparse(_end_date)

        service_name = d.pop("ServiceName", UNSET)

        priority = d.pop("Priority", UNSET)

        pre_padding_seconds = d.pop("PrePaddingSeconds", UNSET)

        post_padding_seconds = d.pop("PostPaddingSeconds", UNSET)

        is_pre_padding_required = d.pop("IsPrePaddingRequired", UNSET)

        parent_backdrop_item_id = d.pop("ParentBackdropItemId", UNSET)

        parent_backdrop_image_tags = cast(List[str], d.pop("ParentBackdropImageTags", UNSET))

        is_post_padding_required = d.pop("IsPostPaddingRequired", UNSET)

        _keep_until = d.pop("KeepUntil", UNSET)
        keep_until: Union[Unset, KeepUntil]
        if isinstance(_keep_until, Unset):
            keep_until = UNSET
        else:
            keep_until = KeepUntil(_keep_until)

        record_any_time = d.pop("RecordAnyTime", UNSET)

        skip_episodes_in_library = d.pop("SkipEpisodesInLibrary", UNSET)

        record_any_channel = d.pop("RecordAnyChannel", UNSET)

        keep_up_to = d.pop("KeepUpTo", UNSET)

        record_new_only = d.pop("RecordNewOnly", UNSET)

        days = []
        _days = d.pop("Days", UNSET)
        for days_item_data in _days or []:
            days_item = DayOfWeek(days_item_data)

            days.append(days_item)

        _day_pattern = d.pop("DayPattern", UNSET)
        day_pattern: Union[Unset, None, DayPattern]
        if _day_pattern is None:
            day_pattern = None
        elif isinstance(_day_pattern, Unset):
            day_pattern = UNSET
        else:
            day_pattern = DayPattern(_day_pattern)

        _image_tags = d.pop("ImageTags", UNSET)
        image_tags: Union[Unset, None, SeriesTimerInfoDtoImageTags]
        if _image_tags is None:
            image_tags = None
        elif isinstance(_image_tags, Unset):
            image_tags = UNSET
        else:
            image_tags = SeriesTimerInfoDtoImageTags.from_dict(_image_tags)

        parent_thumb_item_id = d.pop("ParentThumbItemId", UNSET)

        parent_thumb_image_tag = d.pop("ParentThumbImageTag", UNSET)

        parent_primary_image_item_id = d.pop("ParentPrimaryImageItemId", UNSET)

        parent_primary_image_tag = d.pop("ParentPrimaryImageTag", UNSET)

        series_timer_info_dto = cls(
            id=id,
            type=type,
            server_id=server_id,
            external_id=external_id,
            channel_id=channel_id,
            external_channel_id=external_channel_id,
            channel_name=channel_name,
            channel_primary_image_tag=channel_primary_image_tag,
            program_id=program_id,
            external_program_id=external_program_id,
            name=name,
            overview=overview,
            start_date=start_date,
            end_date=end_date,
            service_name=service_name,
            priority=priority,
            pre_padding_seconds=pre_padding_seconds,
            post_padding_seconds=post_padding_seconds,
            is_pre_padding_required=is_pre_padding_required,
            parent_backdrop_item_id=parent_backdrop_item_id,
            parent_backdrop_image_tags=parent_backdrop_image_tags,
            is_post_padding_required=is_post_padding_required,
            keep_until=keep_until,
            record_any_time=record_any_time,
            skip_episodes_in_library=skip_episodes_in_library,
            record_any_channel=record_any_channel,
            keep_up_to=keep_up_to,
            record_new_only=record_new_only,
            days=days,
            day_pattern=day_pattern,
            image_tags=image_tags,
            parent_thumb_item_id=parent_thumb_item_id,
            parent_thumb_image_tag=parent_thumb_image_tag,
            parent_primary_image_item_id=parent_primary_image_item_id,
            parent_primary_image_tag=parent_primary_image_tag,
        )

        return series_timer_info_dto



from enum import Enum


class ChannelItemSortField(str, Enum):
    COMMUNITYPLAYCOUNT = "CommunityPlayCount"
    COMMUNITYRATING = "CommunityRating"
    DATECREATED = "DateCreated"
    NAME = "Name"
    PLAYCOUNT = "PlayCount"
    PREMIEREDATE = "PremiereDate"
    RUNTIME = "Runtime"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="BrandingOptions")


@_attrs_define
class BrandingOptions:
    """The branding options.

    Attributes:
        login_disclaimer (Union[Unset, None, str]): Gets or sets the login disclaimer.
        custom_css (Union[Unset, None, str]): Gets or sets the custom CSS.
        splashscreen_enabled (Union[Unset, bool]): Gets or sets a value indicating whether to enable the splashscreen.
    """

    login_disclaimer: Union[Unset, None, str] = UNSET
    custom_css: Union[Unset, None, str] = UNSET
    splashscreen_enabled: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        login_disclaimer = self.login_disclaimer
        custom_css = self.custom_css
        splashscreen_enabled = self.splashscreen_enabled

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if login_disclaimer is not UNSET:
            field_dict["LoginDisclaimer"] = login_disclaimer
        if custom_css is not UNSET:
            field_dict["CustomCss"] = custom_css
        if splashscreen_enabled is not UNSET:
            field_dict["SplashscreenEnabled"] = splashscreen_enabled

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        login_disclaimer = d.pop("LoginDisclaimer", UNSET)

        custom_css = d.pop("CustomCss", UNSET)

        splashscreen_enabled = d.pop("SplashscreenEnabled", UNSET)

        branding_options = cls(
            login_disclaimer=login_disclaimer,
            custom_css=custom_css,
            splashscreen_enabled=splashscreen_enabled,
        )

        return branding_options



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="ValidatePathDto")


@_attrs_define
class ValidatePathDto:
    """Validate path object.

    Attributes:
        validate_writable (Union[Unset, bool]): Gets or sets a value indicating whether validate if path is writable.
        path (Union[Unset, None, str]): Gets or sets the path.
        is_file (Union[Unset, None, bool]): Gets or sets is path file.
    """

    validate_writable: Union[Unset, bool] = UNSET
    path: Union[Unset, None, str] = UNSET
    is_file: Union[Unset, None, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        validate_writable = self.validate_writable
        path = self.path
        is_file = self.is_file

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if validate_writable is not UNSET:
            field_dict["ValidateWritable"] = validate_writable
        if path is not UNSET:
            field_dict["Path"] = path
        if is_file is not UNSET:
            field_dict["IsFile"] = is_file

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        validate_writable = d.pop("ValidateWritable", UNSET)

        path = d.pop("Path", UNSET)

        is_file = d.pop("IsFile", UNSET)

        validate_path_dto = cls(
            validate_writable=validate_writable,
            path=path,
            is_file=is_file,
        )

        return validate_path_dto



from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.base_item_dto import BaseItemDto
from ...models.problem_details import ProblemDetails
from ...types import UNSET, Response, Unset


def _get_kwargs(
    year: int,
    *,
    user_id: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    params["userId"] = user_id

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "/Years/{year}".format(
            year=year,
        ),
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, BaseItemDto, ProblemDetails]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = BaseItemDto.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = ProblemDetails.from_dict(response.json())

        return response_404
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = cast(Any, None)
        return response_403
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, BaseItemDto, ProblemDetails]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    year: int,
    *,
    client: AuthenticatedClient,
    user_id: Union[Unset, None, str] = UNSET,
) -> Response[Union[Any, BaseItemDto, ProblemDetails]]:
    """Gets a year.

    Args:
        year (int):
        user_id (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BaseItemDto, ProblemDetails]]
    """

    kwargs = _get_kwargs(
        year=year,
        user_id=user_id,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    year: int,
    *,
    client: AuthenticatedClient,
    user_id: Union[Unset, None, str] = UNSET,
) -> Optional[Union[Any, BaseItemDto, ProblemDetails]]:
    """Gets a year.

    Args:
        year (int):
        user_id (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BaseItemDto, ProblemDetails]
    """

    return sync_detailed(
        year=year,
        client=client,
        user_id=user_id,
    ).parsed


async def asyncio_detailed(
    year: int,
    *,
    client: AuthenticatedClient,
    user_id: Union[Unset, None, str] = UNSET,
) -> Response[Union[Any, BaseItemDto, ProblemDetails]]:
    """Gets a year.

    Args:
        year (int):
        user_id (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BaseItemDto, ProblemDetails]]
    """

    kwargs = _get_kwargs(
        year=year,
        user_id=user_id,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    year: int,
    *,
    client: AuthenticatedClient,
    user_id: Union[Unset, None, str] = UNSET,
) -> Optional[Union[Any, BaseItemDto, ProblemDetails]]:
    """Gets a year.

    Args:
        year (int):
        user_id (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BaseItemDto, ProblemDetails]
    """

    return (
        await asyncio_detailed(
            year=year,
            client=client,
            user_id=user_id,
        )
    ).parsed
